Summary: The Linux kernel (the core of the Linux operating system)

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows and
# no contrary --with/--without arguments are given on the command line.

%define buildup 1
%define buildsmp 1
%define buildBOOT 1
%define buildhugemem 1
%define buildsource 1


# Versions of various parts

#
# Polite request for people who spin their own kernel rpms:
# please modify the "release" field in a way that identifies
# that the kernel isn't the stock RHL kernel, for example by
# adding some text to the end of the version number.
#
%define release 15.0.4.EL
%define sublevel 21
%define kversion 2.4.%{sublevel}
# /usr/src/%{kslnk} -> /usr/src/linux-%{KVERREL}
%define kslnk linux-2.4
%define KVERREL %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}

# groups of related archs
%define all_x86 i386 i686 athlon
%define all_x86_64 x86_64 ia32e
%define all_ppc64 ppc64 ppc64pseries ppc64iseries

#
# RPM magic
#
%define _missing_doc_files_terminate_build    0
%define _unpackaged_files_terminate_build 0
# disable build root strip policy
%define __spec_install_post /usr/lib/rpm/brp-compress || :


# Override generic defaults with per-arch defaults 
# These must ONLY be "0", never "1"

# First, architecture-specific kernels off on all other archs (ifnarch)
%ifnarch i686
%define buildhugemem 0
%endif
%ifnarch i386 
%define buildBOOT 0
%endif
%ifnarch i386 x86_64 ia64 s390 s390x ppc64
%define buildsource 0
%endif

# Second, per-architecture exclusions (ifarch)
%ifarch i386
%define buildsmp 0
%define buildup 0
%endif
%ifarch i586
%define buildsmp 0
%endif
%ifarch s390 s390x
%define buildsmp 0
%endif
%ifarch ppc64
%define buildup 0
%define buildsmp 0
%define buildBOOT 0
%define buildhugemem 0
%endif
%ifarch ppc64pseries ppc64iseries
%define buildsmp 0
%endif
%ifarch ia64
%define buildsmp 0
%endif
%ifarch ia32e
%define buildsmp 0
%endif

%ifarch ia64
%if %xoslinux
%define image_install_path boot/efi/EFI/xos
%else
%define image_install_path boot/efi/EFI/redhat
%endif
%else
%define image_install_path boot
%endif

%ifarch %{all_x86} %{all_x86_64}
%define buildtarget bzImage
%endif
%ifarch s390 s390x
%define buildtarget image
%endif
%ifarch %{all_ppc64}
%define buildtarget boot
%endif
%ifarch ia64
%define buildtarget compressed
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.4 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp <= 2.3.15, pcmcia-cs <= 3.1.20, isdn4k-utils <= 3.0, mount < 2.10r-5, nfs-utils < 0.3.1, e2fsprogs < 1.22 

# 
# Then a series of requirements that are Red Hat specific, either 
# because we add patches for something, or the older versions have 
# problems with the newer kernel or lack certain things that make 
# integration in the distro harder than needed.
#
%define package_conflicts  cipe < 1.4.5, tux < 2.1.0, kudzu <= 0.92, initscripts < 6.41, dev < 3.2-7, iptables < 1.2.5-3, bcm5820 < 1.81, nvidia-rh72 <= 1.0, oprofile < 0.4, ipsec-tools <= 0.2.2-5, s390utils < 1.2.4-3

#
# Several packages had bugs in them that became obvious when the NPTL
# threading code got integrated. 
#
%define nptl_conflicts SysVinit < 2.84-13, pam < 0.75-48, vixie-cron < 3.0.1-73, privoxy < 3.0.0-8, spamassassin < 2.44-4.8.x,  cups < 1.1.17-13

#
# Things that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, modutils >=  2.4.18, initscripts >= 5.83, mkinitrd >= 3.2.6


Name: kernel
Group: System Environment/Kernel
License: GPLv2
Version: %{kversion}
Release: %{release}.XOS.1
ExclusiveArch: %{all_x86} %{all_x86_64} s390 s390x %{all_ppc64} ia64
ExclusiveOS: Linux
Obsoletes: kernel-modules
Provides: kernel = %{version}
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0 
Autoreqprov: no
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}

BuildPreReq: modutils >= 2.4.21-1, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildPreReq: bzip2, findutils, dev, gzip, m4, perl
# BuildProvides: rhbuildsys(ParallelBuild) <= 8
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
BuildRequires: gcc >= 2.96-98

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-%{kversion}.tar.bz2

Source10: COPYING.modules
Source11: linux-rhconfig.h
Source12: linux-merge-config.awk
Source13: linux-merge-modules.awk
Source14: linux-modules-unsupported
Source15: linux-modules-unsupported-hugemem

Source20: kernel-%{kversion}-i386.config
Source21: kernel-%{kversion}-i386-BOOT.config
Source22: kernel-%{kversion}-i686.config
Source23: kernel-%{kversion}-i686-smp.config
Source24: kernel-%{kversion}-i586.config
Source25: kernel-%{kversion}-i586-smp.config
Source26: kernel-%{kversion}-i686-hugemem.config
Source27: kernel-%{kversion}-athlon.config
Source28: kernel-%{kversion}-athlon-smp.config
Source29: kernel-%{kversion}-x86_64.config
Source30: kernel-%{kversion}-x86_64-smp.config
Source31: kernel-%{kversion}-s390.config
Source32: kernel-%{kversion}-s390x.config
Source33: kernel-%{kversion}-ppc64pseries.config
Source34: kernel-%{kversion}-ppc64iseries.config
Source35: kernel-%{kversion}-ia64.config
Source36: kernel-%{kversion}-ppc64.config
Source37: kernel-%{kversion}-ia32e.config

#
# Patches 0 through 99 are meant for core subsystem upgrades
#

Patch2: linux-2.4.21-dailybk.patch
# select bits from 2.4 upstream
Patch3: linux-2.4.21-select-upstream-bits.patch
# -ac patch, minus ACPI, dm, irqbalance, XAPIC and XFS
Patch4: linux-2.4.21-selected-ac-bits.patch

Patch10: linux-2.4.20-o1-nptl.patch
Patch20: linux-2.4.21-o1-fairness.patch
Patch30: linux-2.4.21-compat.patch
Patch40: linux-2.4.21-o1-ht.patch

# 
# Patches 100 through 500 are architecture specific patches
# Each architecture has 80 slots reserved.
#

# x86 is 100 - 179
Patch100: linux-2.4.20-x86-syscalls.patch
Patch110: linux-2.4.20-x86-oprofile.patch
Patch115: linux-2.4.21-x86-acpi.patch
Patch120: linux-2.4.21-x86-xapic.patch
Patch125: linux-2.4.21-x86-ucode-loader.patch
Patch130: linux-2.4.21-amd-golem.patch

# X86-64 is 180 - 259
Patch180: linux-2.4.21-amd64.patch
Patch181: linux-2.4.21-amd64-o1.patch
Patch190: linux-2.4.20-amd64-oprofile.patch
Patch200: linux-2.4.21-amd64-compat.patch
Patch201: linux-2.4.21-amd64-coredump-fix.patch
Patch202: linux-2.4.21-amd64-acpi.patch
Patch203: linux-2.4.21-amd64-siginfo_t.patch
Patch204: linux-2.4.21-amd64-numa-support.patch
Patch210: linux-2.4.21-ia32e-support.patch

# IA64 is 260 - 339
Patch260: linux-2.4.20-ia64-syscalls.patch
Patch262: linux-2.4.20-ia64-core.patch
Patch264: linux-2.4.20-ia64-signals.patch
Patch266: linux-2.4.20-ia64-irq.patch
Patch268: linux-2.4.20-ia64-o1-nptl.patch
Patch270: linux-2.4.21-ia64-compat.patch
Patch272: linux-2.4.20-ia64-oprofile.patch
Patch274: linux-2.4.20-ia64-mcadump.patch
Patch276: linux-2.4.21-ia64-fancyiommu.patch
Patch278: linux-2.4.21-ia64-cyclone.patch

# PPC is 340 - 419
Patch340: linux-2.4.21-ppc64-core.patch
Patch341: linux-2.4.21-early-console.patch
Patch342: linux-2.4.21-iseries-drivers.patch
Patch343: linux-2.4.21-ppc64-nptl.patch
Patch344: linux-2.4.21-ppc64-aio.patch
Patch345: linux-2.4.21-ppc64-syscalls.patch
Patch346: linux-2.4.21-ppc64-flags.patch
Patch347: linux-2.4.21-ppc64-biarch.patch
Patch348: linux-2.4.21-ppc64-pseries-makefile.patch
Patch349: linux-2.4.21-ppc64-dump_fpu.patch
Patch350: linux-2.4.21-ppc64-kallsyms.patch
Patch351: linux-2.4.21-ppc64-ptrace.patch
Patch352: linux-2.4.20-ppc64-bitops.patch
Patch353: linux-2.4.21-ppc64-compat.patch
Patch354: linux-2.4.21-ppc64-strip-kernel.patch
Patch355: linux-2.4.21-ppc64-oprofile.patch
Patch356: linux-2.4.21-ppc64-wchan.patch
Patch357: linux-2.4.21-ppc64-scsi_timeout.patch
Patch358: linux-2.4.21-ppc64-ethtool-ioctl32.patch
Patch359: linux-2.4.21-ppc64-enable-xmon.patch
Patch360: linux-2.4.21-ppc64-ras-support.patch
Patch361: linux-2.4.21-ppc64-pci-multifunc.patch
Patch362: linux-2.4.21-ppc64-power-blade.patch
Patch363: linux-2.4.21-ppc64-lparcfg.patch
Patch364: linux-2.4.21-ppc64-segtab.patch

# S390 is 420 - 499
Patch420: linux-2.4.20-s390-common.patch
Patch422: linux-2.4.20-s390-o1-nptl.patch
Patch432: linux-2.4.20-s390-aio.patch
Patch437: linux-2.4.20-s390-compat.patch
Patch439: linux-2.4.20-s390-elfper.patch
Patch440: linux-2.4.20-s390-maxargs25.patch
Patch441: linux-2.4.20-s390-lcs.patch
Patch442: linux-2.4.20-s390-oprofile.patch
Patch443: linux-2.4.21-s390-bug97055.patch
Patch444: linux-2.4.21-s390-ctc_carrier.patch
Patch459: linux-2.4.20-s390-make390x.patch
Patch460: linux-2.4.20-s390-misc.patch
Patch461: linux-2.4.21-s390-cio.patch
Patch462: linux-2.4.21-s390-ctc-locking.patch
Patch463: linux-2.4.21-s390-iucv-update.patch

#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#
Patch600: linux-2.4.0-nonintconfig.patch
Patch610: linux-2.4.18-flock.patch
Patch620: linux-2.4.7-quotareturn.patch
Patch630: linux-2.2.16-rhconfig.patch
Patch640: linux-2.4.2-changeloop.patch
Patch650: linux-2.4.18-loopfixes.patch
Patch660: linux-2.4.2-scsi_scan.patch
Patch670: linux-2.4.9-kksymoops.patch
Patch680: linux-2.4.9-kallsyms.patch
Patch690: linux-2.4.18-dmi-hall-of-shame.patch
Patch700: linux-2.4.20-extra_cflags.patch
Patch710: linux-2.4.18-laptopbits.patch
Patch720: linux-2.4.21-binfmt-elf.patch
Patch730: linux-2.4.20-pci_64b_bar.patch
Patch750: linux-2.4.20-aio.patch
Patch770: linux-2.4.20-varyio.patch
Patch780: linux-2.4.20-superbh.patch
Patch781: linux-2.4.20-superbh-aio.patch
Patch790: linux-2.4.20-oprofile.patch
Patch800: linux-2.4.21-semtimedop.patch
Patch810: linux-2.4.21-pci_large_bus.patch
Patch820: linux-2.4.21-logbufsize.patch
Patch830: linux-2.4.20-elevator.patch
Patch840: linux-2.4.21-tux.patch
Patch850: linux-2.4.21-odirect.patch
Patch860: linux-2.4.21-semaphore-scale.patch
Patch870: linux-2.4.21-sysrq-allcpus.patch
Patch871: linux-2.4.21-sticky-sysrq.patch
Patch880: linux-2.4.21-iorl.patch
Patch890: linux-2.4.21-compat-32.patch
Patch900: linux-2.4.21-binfmt-interp.patch
Patch910: linux-2.4.21-strncpy-zero-pad.patch

#
# Patches 1000 to 2000 are reserved for VM changes.
#
Patch1000: linux-2.4.21-rmap.patch
Patch1020: linux-2.4.21-rmap-updates.patch
Patch1025: linux-2.4.21-rmap-chain-ptep.patch
Patch1030: linux-2.4.21-iowait.patch
Patch1040: linux-2.4.20-virtual_memmap.patch
Patch1050: linux-2.4.21-mlock.patch
Patch1060: linux-2.4.21-x86-4Gsplit.patch
Patch1070: linux-2.4.20-fix-pausing.patch
Patch1080: linux-2.4.21-dma-isolation.patch
Patch1090: linux-2.4.21-vma-merging.patch
Patch1100: linux-2.4.21-exec-shield.patch
Patch1110: linux-2.4.21-pagecache-scale.patch
Patch1120: linux-2.4.21-flexible-mmap.patch
Patch1130: linux-2.4.21-remap_file_pages.patch
Patch1140: linux-2.4.20-statm.patch
Patch1150: linux-2.4.21-hugetlbfs.patch
Patch1151: linux-2.4.21-hugetlbfs-ia64.patch
Patch1160: linux-2.4.21-tunable-overcommit.patch
Patch1170: linux-2.4.21-x86-4G-lockless.patch
Patch1190: linux-2.4.21-crosshost-mmap.patch
Patch1200: linux-2.4.21-3G-personality.patch
Patch1210: linux-2.4.21-s390-dirtybit.patch
Patch1220: linux-2.4.21-bufhead-reduction.patch
Patch1223: linux-2.4.21-refill-inactive-zone.patch
Patch1224: linux-2.4.21-ptes-from-highmem.patch
Patch1225: linux-2.4.21-page-deact-scale.patch
Patch1226: linux-2.4.21-ramfs-wired-lists.patch
Patch1228: linux-2.4.21-enhanced-show-mem.patch
Patch1230: linux-2.4.21-aio-safe-free-pages.patch
Patch1240: linux-2.4.21-ppc64-pte-hash-lock.patch

#
# Patches 2000 to 5000 are reserved for the network protocol subsystem
#
Patch2000: linux-2.4.21-ipsec.patch
Patch2010: linux-2.4.21-ipsec-compilefixes.patch
Patch2020: linux-2.4.21-igmpv3.patch
Patch2030: linux-2.4.21-ipvs.patch
Patch2040: linux-2.4.21-max-addr-len.patch
Patch2050: linux-2.4.20-aio-poll-and-net.patch
Patch2060: linux-2.4.21-nptl-network.patch
Patch2070: linux-2.4.21-netfixes.patch
Patch2080: linux-2.4.21-ethtool_ops.patch

#
# Patches 5000 to 7000 are reserved for bugfixes, changes and updates to
# existing drivers and filesystems
#
Patch5000: linux-2.4.18-nousb.patch
Patch5010: linux-2.4.0-test11-vidfail.patch
Patch5020: linux-2.4.0-e820.patch
Patch5030: linux-2.4.2-page_bitmap.patch
Patch5040: linux-2.4.0-apic-quiet.patch
Patch5050: linux-2.4.20-irixnfs.patch
Patch5060: linux-2.4.3-pcipenalty.patch
Patch5070: linux-2.4.2-keyboardsilence.patch
Patch5080: linux-2.4.7-scsitimeout.patch
Patch5090: linux-2.4.9-freevxfs.patch
Patch5100: linux-2.4.9-nmiprofiling.patch
Patch5110: linux-2.4.18-moreunnamed.patch
Patch5120: linux-2.4.20-lvm-updates.patch
Patch5121: linux-2.4.17-lvm-bulkcopy.patch
Patch5122: linux-2.4.17-lvm-pvmove.patch
Patch5123: linux-2.4.18-lvm-VFSlock.patch
Patch5124: linux-2.4.21-lvm-compat.patch
Patch5130: linux-2.4.18-input-35215.patch
Patch5140: linux-2.4.20-egenera-scan-new-devices.patch
Patch5160: linux-2.4.9-scsilun0.patch
Patch5170: linux-2.4.18-netdump.patch
Patch5180: linux-2.4.20-cenatek.patch
Patch5220: linux-2.4.7-suspend.patch
Patch5230: linux-2.4.18-orinoco.patch
Patch5250: linux-2.4.18-scsidevices.patch
Patch5260: linux-2.4.18-usb-bug56856.patch
Patch5270: linux-2.4.20-usb-bug81091.patch
Patch5280: linux-2.4.20-usb-bug82546.patch
Patch5288: linux-2.4.20-usb-bug98264.patch
Patch5290: linux-2.4.20-usb-updates.patch
Patch5300: linux-2.4.21-sound-updates.patch
Patch5400: linux-2.4.20-deepersymlink.patch
Patch5410: linux-2.4.20-acpi-updates.patch
Patch5411: linux-2.4.21-ia64-acpi.patch
Patch5412: linux-2.4.21-ipmi-acpi-fix.patch
Patch5413: linux-2.4.21-acpi-serial.patch
Patch5420: linux-2.4.21-matroxfb.patch
Patch5430: linux-2.4.21-sym53c8xx.patch
Patch5440: linux-2.4.21-cmpci-update.patch
Patch5450: linux-2.4.21-raid-autorun.patch
Patch5460: linux-2.4.20-nfs-odirectfix.patch
Patch5490: linux-2.4.20-nfsd-deadsocks.patch
Patch5500: linux-2.4.20-nfsd-flowcontrol.patch
Patch5520: linux-2.4.21-xattr-core.patch
Patch5530: linux-2.4.21-xattr-ext3.patch
Patch5540: linux-2.4.21-xattr-syscalls.patch
Patch5550: linux-2.4.21-acl-core.patch
Patch5560: linux-2.4.21-acl-ext3.patch
Patch5570: linux-2.4.21-acl-nfs.patch
Patch5580: linux-2.4.21-xattr-vm.patch
Patch5590: linux-2.4.21-lockd-svc.patch
Patch5600: linux-2.4.21-lockd-blkreq.patch
Patch5610: linux-2.4.20-nfsd-expacl.patch
Patch5620: linux-2.4.21-nfs-tcp-discon-race.patch
Patch5630: linux-2.4.21-nfs-tcp-reconn.patch
Patch5640: linux-2.4.21-nfsd-aclfix.patch
Patch5650: linux-2.4.21-lockd-resvport.patch
Patch5660: linux-2.4.21-nfs-acl-otw.patch
Patch5670: linux-2.4.21-scsi-timer.patch
Patch5675: linux-2.4.21-ips-update.patch
Patch5676: linux-2.4.21-ips-backup-61052.patch
Patch5680: linux-2.4.21-cciss-update.patch
Patch5690: linux-2.4.21-megaraid-update.patch
Patch5691: linux-2.4.21-megaraid-varyio.patch
Patch5692: linux-2.4.21-megaraid-backup-2009.patch
Patch5700: linux-2.4.21-nfs-tcp-corrup.patch
Patch5710: linux-2.4.21-nfs-xdr-kmap.patch
Patch5720: linux-2.4.21-nfs-64aligned.patch
Patch5730: linux-2.4.21-aic7xxx-update.patch
Patch5731: linux-2.4.21-aic7xxx-iorl.patch
Patch5732: linux-2.4.21-aic7xxx-varyio.patch
Patch5740: linux-2.4.21-cpqarray-update.patch
Patch5745: linux-2.4.21-aacraid-update.patch
Patch5750: linux-2.4.20-autofs4-update.patch
Patch5751: linux-2.4.20-autofs4-reghost.patch
Patch5760: linux-2.4.21-3ware-update.patch
Patch5770: linux-2.4.21-emu10k1.patch
Patch5780: linux-2.4.21-acl-jfs.patch
Patch5790: linux-2.4.21-nfs-failover.patch
Patch5800: linux-2.4.21-scsi-device-list.patch
Patch5810: linux-2.4.21-lvm-rwsem-irq.patch
Patch5820: linux-2.4.21-ext3-acl-update.patch
Patch5821: linux-2.4.21-jbd-acl-update.patch
Patch5822: linux-2.4.21-nfsd-acl-hangfix.patch
Patch5830: linux-2.4.21-nfsd-reusefix.patch
Patch5840: linux-2.4.21-nfsd-acl-update.patch
Patch5850: linux-2.4.21-nfs-clu-opps.patch
Patch5860: linux-2.4.21-nfs-highmemfix.patch
Patch5870: linux-2.4.21-cdrom-compat.patch
Patch5880: linux-2.4.21-nfs-softirqs.patch
Patch5890: linux-2.4.21-knfsd-symlink-error.patch
Patch5900: linux-2.4.21-knfsd-missing-locks.patch
Patch5910: linux-2.4.21-lockd-blockedlks.patch
Patch5920: linux-2.4.21-i810-esb5.patch
Patch5930: linux-2.4.21-netdrvr-fixes.patch
Patch5931: linux-2.4.21-e100-update.patch
Patch5932: linux-2.4.21-e1000-update.patch
Patch5935: linux-2.4.21-aironet-update.patch
Patch5940: linux-2.4.21-usb-ohci.patch
Patch5950: linux-2.4.21-lockd-sysctlif.patch
Patch5960: linux-2.4.21-sunrpc-calldecode.patch
Patch5970: linux-2.4.21-tg3.patch
Patch5980: linux-2.4.21-pci-ids.patch
Patch5990: linux-2.4.21-md-multipath.patch
Patch6000: linux-2.4.21-nfs-vxfs.patch
Patch6010: linux-2.4.21-lastsector.patch
Patch6020: linux-2.4.18-netdump-drivers.patch
Patch6030: linux-2.4.21-fdunshare.patch
Patch6040: linux-2.4.21-nfs-nfsrootfail.patch
Patch6050: linux-2.4.21-nfs-accesscache.patch
Patch6060: linux-2.4.21-nfs-solaris_acls.patch
Patch6065: linux-2.4.21-nfs-stack-usage.patch
Patch6070: linux-2.4.21-nfs-callreserve.patch
Patch6080: linux-2.4.21-nfs-softmnts.patch
Patch6090: linux-2.4.21-nfs-updates.patch
Patch6100: linux-2.4.21-proc-tty-driver.patch
Patch6110: linux-2.4.21-ncpfs-updates.patch
Patch6200: linux-2.4.21-gfs-enablers.patch

#
# Patches 7000 to 8000 are reserved for scalability fixes
# that touch various subsystems
#
Patch7000: linux-2.4.21-gendisk-scale.patch
Patch7010: linux-2.4.21-kstat-percpu.patch
Patch7020: linux-2.4.21-gettimeofday-scale.patch
Patch7030: linux-2.4.21-scsi-affine-queue.patch
Patch7040: linux-2.4.21-scsi-softirq.patch
Patch7050: linux-2.4.21-scsi-rqlock-scale.patch
Patch7055: linux-2.4.21-scsi-queue-fixes.patch
Patch7060: linux-2.4.21-scalable-timers.patch
Patch7070: linux-2.4.21-slab-scale.patch
Patch7080: linux-2.4.21-kiobuf-fixes.patch
Patch7081: linux-2.4.21-aio-odirect-blkdev.patch
Patch7090: linux-2.4.21-proc_irq_many.patch
Patch7100: linux-2.4.21-process_acct.patch
Patch7110: linux-2.4.21-rawio-readv-writev.patch
Patch7120: linux-2.4.21-sync-supers.patch
Patch7130: linux-2.4.21-dcache-priority.patch
Patch7140: linux-2.4.21-softirq-defer.patch
Patch7150: linux-2.4.21-s390-on-demand-timer.patch

#
# Patches 8000 to 9000 are reserved for new drivers
#
Patch8000: linux-2.4.9-addon.patch
Patch8010: linux-2.4.18-megarac.patch
Patch8020: linux-2.4.18-wvlan-cs.patch
Patch8030: linux-2.4.18-ecc.patch
Patch8040: linux-2.4.6-bcm5820.patch
Patch8050: linux-2.4.7-tulip.patch
Patch8060: linux-2.4.0-cipe-1.4.5.patch
Patch8061: linux-2.4.21-cipe-ipsec.patch
Patch8070: linux-2.4.20-lm_sensors.patch
Patch8080: linux-2.4.9-qla2200.patch
Patch8081: linux-2.4.9-qla2200-backup-60600b11.patch
Patch8090: linux-2.4.9-aep.patch
Patch8100: linux-2.4.18-loop-cryptoapi.patch
Patch8110: linux-2.4.18-audigy.patch
Patch8120: linux-2.4.21-bonding-core.patch
Patch8121: linux-2.4.21-bonding.patch
Patch8140: linux-2.4.21-sata.patch
Patch8142: linux-2.4.21-sata-taroon.patch
Patch8143: linux-2.4.21-ich6-pata.patch
Patch8150: linux-2.4.21-fusion.patch
Patch8151: linux-2.4.21-fusion-varyio.patch
Patch8152: linux-2.4.21-fusion-backup-20505.patch
Patch8160: linux-2.4.21-icom.patch
Patch8161: linux-2.4.21-icom-serial-debugger.patch
Patch8170: linux-2.4.21-hangcheck-timer.patch
Patch8180: linux-2.4.21-agp3gart.patch
Patch8181: linux-2.4.21-drm-updates.patch
Patch8190: linux-2.4.20-s390-qdio.patch
Patch8200: linux-2.4.20-s390-qeth.patch
Patch8210: linux-2.4.21-s390-zcrypt.patch
Patch8220: linux-2.4.21-s390-zfcp.patch
Patch8230: linux-2.4.21-b44.patch
Patch8240: linux-2.4.21-ppc64-ipr.patch
Patch8250: linux-2.4.21-syscall-auditing.patch


#
# 10000 to 20000 is for stuff that has to come last due to the
# amount of drivers they touch. But only theese should go here. 
#

# file offset handling fixes
Patch10000: linux-2.4.21-file-offset-fixes.patch

# fix a lot of warnings in the plain kernel and previous patches
Patch10010: linux-2.4.1-compilefailure.patch

# several small tweaks not worth their own patch
Patch10020: linux-2.4.18-smallpatches.patch

# add missing MODULE_LICENSE() tags
Patch10030: linux-2.4.18-missing-license-tags.patch

# snip out some luxury code when CONFIG_SMALL is on, for -BOOT kernel
Patch10040: linux-2.4.21-config-small.patch


# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

%define xoslinux %(test -f /etc/xos-release && echo 1 || echo 0)

%package source
Summary: The source code for the Linux kernel.
Group: Development/System
Prereq: fileutils
Requires: gawk, make
Requires: gcc >= 2.96-98

%package doc
Summary: Various documentation bits found in the kernel source.
Group: Documentation

%description 
The kernel package contains the Linux kernel (vmlinuz), the core of your
X/OS Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build custom/third party device
drivers. The source files can also be used to build a custom kernel that is
better tuned to your particular hardware. Make sure you understand the
support implications of building your own custom kernel.

%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files. 

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.

%if ! %xoslinux

%package unsupported
Summary: An extra, unsupported, set of kernel modules
Group: System Environment/Kernel
Provides: kernel-modules

%description unsupported
This package contains extra modules for those drivers which are present in
the kernel org kernel, but have not been tested by X/OS. These drivers
are provided as a courtesy and are not officially supported by X/OS.

%package smp-unsupported
Summary: An extra, unsupported, set of kernel modules
Group: System Environment/Kernel
Provides: kernel-modules

%description smp-unsupported
This package contains extra modules for those drivers which are present in
the kernel org kernel, but have not been tested by X/OS. These drivers
are provided as a courtesy and are not officially supported by X/OS.

%package hugemem-unsupported
Summary: An extra, unsupported, set of kernel modules
Group: System Environment/Kernel
Provides: kernel-modules

%description hugemem-unsupported
This package contains extra modules for those drivers which are present in
the kernel org kernel, but have not been tested by X/OS. These drivers
are provided as a courtesy and are not officially supported by X/OS.

%endif

%package smp
Summary: The Linux kernel compiled for SMP machines.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}
Obsoletes: kernel-enterprise < 2.4.10

%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs.

Install the kernel-smp package if your machine uses two or more CPUs.

%package hugemem
Summary: The Linux Kernel for machines with more than 16 Gigabytes of memory.
Group: System Environment/Kernel
Provides: kernel = %{version}
Provides: kernel-drm = 4.1.0, kernel-drm = 4.2.0, kernel-drm = 4.3.0
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}


%description hugemem
This package includes a kernel that has appropriate configuration options
enabled for Pentium III machines with 16 Gigabytes or more of physical memory.

%package BOOT
Summary: The version of the Linux kernel used on installation boot disks.
Group: System Environment/Kernel
Provides: kernel = %{version}
Prereq: %{kernel_prereq}
Conflicts: %{kernel_dot_org_conflicts}
Conflicts: %{package_conflicts}
Conflicts: %{nptl_conflicts}

%description BOOT
This package includes a trimmed down version of the Linux kernel.
This kernel is used on the installation boot disks only and should not
be used for an installed system, as many features in this kernel are
turned off because of the size constraints of floppy disks.

%prep

%setup -q -n %{name}-%{version} -c
cd linux-%{version}

#
# Patches 0 through 100 are meant for core subsystem upgrades
# 

# update to recent upstream
%patch2 -p1
%patch3 -p1
%patch4 -p1

# O(1) update + NPTL
%patch10 -p1
# O(1) SMP fairness improvement
%patch20 -p1
# generic 32 bit compatibility for 64 bit architectures
%patch30 -p1
# HT scheduler
%patch40 -p1

# 
# Patches 100 through 400 are architecture specific patches
# Each architecture has 20 slots reserved.
#

# x86
# additional syscalls for this tree
%patch100 -p1
# oprofile x86 bits
%patch110 -p1
# larger acpi table size
%patch115 -p1
# clustered apic support
%patch120 -p1
# microcode loader update
%patch125 -p1
# AMD Golem IO-APIC fixup for i686 kernel on AMD64
%patch130 -p1

# X86-64
# Base updates for arch
%patch180 -p1
# Patches specific to o1/nptl support
%patch181 -p1
# oprofile amd64 bits
%patch190 -p1
# 32 bit emulation
%patch200 -p1
# coredump fix
%patch201 -p1
# Backport of ACPI support from 2.5
%patch202 -p1
# correct siginfo_t size for 32 bit emulation
%patch203 -p1
# amd64 NUMA support
%patch204 -p1
# Intel ia32e support
%patch210 -p1

# IA64
# syscalls
%patch260 -p1
# ia64 core architecture updates
%patch262 -p1
# ia64 signal handling stuff
%patch264 -p1
# ia64 irq stuff
%patch266 -p1
# ia64 o1-nptl support
%patch268 -p1
# 32 bit emulation
%patch270 -p1
# oprofile for ia64
%patch272 -p1
# mca dump for ia64
%patch274 -p1
# software io mmu for chipsets without hardware iommu
%patch276 -p1
# cyclone timer support
%patch278 -p1


# s390 s390x
# The kmap_types.h - needed for aio
%patch420 -p1
# O(1) & NPTL, they share some code.
%patch422 -p1
# aio
%patch432 -p1
# 31(32) bit mode updates
%patch437 -p1
# "31 bit init cannot mmap anything" - instead of arch_get_unmapped_area.
%patch439 -p1
# Increase the maximum number of boot arguments for s390.
%patch440 -p1
# lcs
%patch441 -p1
# oprofile.
%patch442 -p1
# kill illegal calls to dst_link_failure from interrupt context.
%patch443 -p1
# implement carrier reporting in ctc, see what happens.
%patch444 -p1
# This is handy: it allows to build rpms outside of buildroots.
# Even in Beehive, it reduces warnings.
%patch459 -p1
# Miscellanea: build fixes.
%patch460 -p1
# cio updates
%patch461 -p1
# ctc locking fixes
%patch462 -p1
# iucv driver fixes
%patch463 -p1

#
# PPC64
#
%patch340 -p1
%patch341 -p1
%patch342 -p1
%patch343 -p1
%patch344 -p1
%patch345 -p1
%patch346 -p1
%patch347 -p1
%patch348 -p1
%patch349 -p1
%patch350 -p1
%patch351 -p1
# explicit typing for ppc64 bitops
%patch352 -p1
# 32 bit emulation
%patch353 -p1
# strip debugging symbols from kernel
%patch354 -p1
# oprofile for ppc64
%patch355 -p1
# make wchan show something useful on ppc64
%patch356 -p1
# some DVD-ROM drives in ppc64 machines need a longer timeout
%patch357 -p1
# ethtool ioctl support for 32-bit compat mode
%patch358 -p1
# xmon enabling at boot-time
%patch359 -p1
# ppc64 revised ras support
%patch360 -p1
# pci multifunction support
%patch361 -p1
# Power Blade (JS20) support
%patch362 -p1
# /proc/ppc64/lparcfg support
%patch363 -p1
# round-robin segment table entry replacement
%patch364 -p1

#
# Patches 600 through 1000 are reserved for bugfixes to the core system
# and patches related to how RPMs are build
#


# This patch adds a "make oldconfig_nonint" which is non-interactive and
# also gives a list of missing options at the end. Useful for automated
# builds (as used in the Red Hat buildsystem).
%patch600 -p1

#
# flock() accounting is broken; disable for 2.4 kernels
#
%patch610 -p1

# tty_write_message needs \r\n -- makes quota messages look nicer
%patch620 -p1
#
# Make "make oldconfig" smarter and have it use the config file for the
# currently running kernel as default.
#
%patch630 -p1
# Al Viro's loopback patch 
%patch640 -p1
%patch650 -p1

# fix lun probing on multilun RAID chassis
%patch660 -p1

#
# kksymoops - automatically decode oopses/backtraces from within the kernel
%patch670 -p1
%patch680 -p1

#
#
# update the list of vendors who can't program a bios
#
%patch690 -p1

#
# use SPEC_CFLAGS to pass in extra CFLAGS options from the spec file
#
%patch700 -p1

#
# add some laptop power consumption improvements
#
%patch710 -p1

# ELF loader fix for PPC64
%patch720 -p1

# bugfix for 64 bit PCI buses on 64 bit systems
%patch730 -p1

# AIO subsystem
%patch750 -p1

# varyio
%patch770 -p1

# superbh
%patch780 -p1
# superbh for AIO
%patch781 -p1

# oprofile
%patch790 -p1 

# semtimedop 32bit compat stuff and arch support
%patch800 -p1

# large pci bus numbers, only for pSeries
%patch810 -p1

# larger log buffer size and boot option
%patch820 -p1

# akpm's IO elevator fix
%patch830 -p1

# tux
%patch840 -p1

# odirect updates
%patch850 -p1

# IPC semaphore scalability patch
%patch860 -p1

# sysrq+C shows the stack dump of all CPUs
%patch870 -p1
# sticky key (with timeout)
%patch871 -p1

# split up the IO request lock into per-queue locks
%patch880 -p1

# 32 bit compatibility for statfs, sysinfo,
%patch890 -p1

# report the right executable file in /proc for interpreted scripts
%patch900 -p1

# strncpy() fixes to zero-pad unused portion of destination buffer
%patch910 -p1


# rmap 15f
%patch1000 -p1

# rmap updates
%patch1020 -p1
%patch1025 -p1

# iowait statistics
%patch1030 -p1

# virtual mem_map for ia64
%patch1040 -p1

# allow users to have locked down pages
%patch1050 -p1

# 4G/4G split
%patch1060 -p1

# fix IO wait stalls
%patch1070 -p1

# DMA zone isolation
%patch1080 -p1

# VMA merging
%patch1090 -p1

# exec-shield
%patch1100 -p1

# pagecache scalability using brlocks
%patch1110 -p1

# flexible mmap, removes the need for TASK_MAPPED_BASE
%patch1120 -p1

# remap_file_pages
%patch1130 -p1

# statm
%patch1140 -p1

# hugetlbfs (x86 and amd64, dummy functions for ppc64 and s390)
%patch1150 -p1
# hugetlbfs for ia64
%patch1151 -p1

# tunable VM overcommit
%patch1160 -p1

# 4G/4G: lockless fastpath access in copy_to/from_user
%patch1170 -p1

# crosshost mmap consistency for distributed filesystems
%patch1190 -p1

# 3G personality for 32 bit programs, to work around bugs in programs
%patch1200 -p1

# correct page dirty bit handling on s390
%patch1210 -p1

# reduction of buf head memory footprint for read-only pages
%patch1220 -p1

# redesign of refill_inactive_zone() for smarter deactivation
%patch1223 -p1

# allocation of pte and ramfs pages from highmem via __GFP_WIRED
%patch1224 -p1

# delayed laundering for better page deactivation scalability
%patch1225 -p1

# wired page lists for more efficient handling of ramfs pages
%patch1226 -p1

# enhanced altsysrq-M with slab, kern-stack, page-table pages
%patch1228 -p1

# deferred LRU page free handling for interrupt level calls
%patch1230 -p1

# ppc64 pte hash table locking rework (disabled until U3)
# %patch1240 -p1


#
# Patches 2000 to 5000 are reserved for network protocol updates
#
# ipsec
%patch2000 -p1
%patch2010 -p1
# igmpv3
%patch2020 -p1
# ipvs
%patch2030 -p1
# Increase MAX_ADDR_LEN from 8 to 32 for Infiniband over IP
%patch2040 -p1
# AIO on sockets
%patch2050 -p1
# fix network permission checks to nptl
%patch2060 -p1
# networking fixes from 2.4.22
%patch2070 -p1
# ethtool_ops
%patch2080 -p1

#
# Patches 5000 to 7000 are reserved for bugfixes to drivers and filesystems
#

#
# Add a "nousb" kernel option to disable all USB loading. On some older
# machines and ACPI-only boxes trying to use ANY usb crashes the machine.
#
%patch5000 -p1

# add vidfail capability; 
# without this patch specifying a framebuffer on the kernel prompt would
# make the boot stop if there's no supported framebuffer device; this is bad
# for the installer floppy that wants to automatically fall back to textmode
# in that case
%patch5010 -p1

#
# add e820 reporting in /proc; needed for anaconda to find out which
# kernels to install
#
%patch5020 -p1

# conservative zone bitmaps to prevent potential memory corruption
%patch5030 -p1
#
# Silence the APIC errors a bit; they are harmless mostly and can happen
# in normal use.
#
%patch5040 -p1

#
# NFS patch fron trond:
# A patch that papers over an IRIX bug. In glibc-2.2 and above, they use
# the new getdents64() syscall even for the 32-bit readdir. As a result, they
# have problems coping with the unsigned 64-bit d_off values that may get
# invalidly returned by some NFSv3 servers, since the values are specified
# to be signed.
# NOTE: You might still have to set the '32bitclients' export option on
# some IRIX servers.

%patch5050 -p1

#
# change IRQ penalty for IRQ 12
# This tries to avoid assigning cardbus irq's to irq12 which is "special"
# for certain laptops that emulate PS/2 hardware via SMM mode.
#
%patch5060 -p1

#
# Silence the PS/2 code for USB keyboards
# It's not uncommon to have no PS/2 keyboard these days
#
%patch5070 -p1

#
# make the scsi timeout longer; 30 seconds is too short for big raid arrays
# with lots of large concurrent requests in flight
#
%patch5080 -p1

#
# make freevxfs autoload when doing mount -t vxfs /dev/foo /mnt/bar
#
%patch5090 -p1


#
# use the nmi interrupt for profiling; this allows the kernel profiler
# to profile even with interrupts disabled. Note: you have to specify the
# nmi watchdog now as well for profiling to work:
# vmlinuz profile=1 nmi_watchdog=1
#
%patch5100 -p1

#
# allow more unnamed mounts by borrowing old, unused major devices
# This is needed if you want more than 255 NFS mounts; some people use the
# "one mount per user" automount setup and they need this if they have more
# than 255 users.
#
%patch5110 -p1



#
# LVM updates:
#
# add important bugfixes from Sistina's LVM-1.0.3
%patch5120 -p1
# Add bulk-copy-via-kiobufs code
%patch5121 -p1
# Add locked copy-and-remap pvmove code
%patch5122 -p1
# LVM atomic snapshot patch: quiesce the filesystem automatically when
# taking snapshots.
%patch5123 -p1
# Allow 32 bit userland on AMD64 and PPC64 to use volumes > 2GB
%patch5124 -p1


#
# Gamepad (all kbds and mice were affected, but we kludged arount it in hplug)
# autoload the proper modules
%patch5130 -p1

# rescan the SCSI bus for new devices when userland asks us to
%patch5140 -p1

#
# allow ioctls to lun0 even if there's no lun0 (needed for some FC kit)
#
%patch5160 -p1

#
# Netdump / Netconsole - crashdumps and kernel messages over
# the network via a lightweight UDP stack that can run with interrupts
# disabled
#
%patch5170 -p1

#
# add cenatek PCI ID's to the ide layer
#
%patch5180 -p1

# 
# Some bioses "forget" to restore pci config space properly on resume;
# the following patch helps them a bit with this
#
%patch5220 -p1

#
# Older orinoco_cs driver that fixes some laptops
#
%patch5230 -p1

#
# Make use of all of the 256 scsi devices available
#
%patch5250 -p1



# SDDR-31 media check
%patch5260 -p1
# ALi in IBM i1200
# Installation BUGs when unmounting usbdevfs (workaround)
%patch5270 -p1
# Yukihiro's pet, will disappear eventually
%patch5280 -p1
# User insists we added usbstor2 (spin_unlock_irq(&io_request_lock))
%patch5288 -p1
# miscellaneous USB fixes
%patch5290 -p1
# miscellaneous sound driver fixes
%patch5300 -p1

# raise symlink recursion level to 8
%patch5400 -p1

# ACPI updates, for IA64 and AMD64
%patch5410 -p1
# acpi for ia64
%patch5411 -p1
# acpi compile fixes for ipmi
%patch5412 -p1
# acpi serial port support
%patch5413 -p1

# matrox framebuffer for pSeries
%patch5420 -p1

# sym53c8xx driver fix for ppc64 Zapata DVD-ROM drives
%patch5430 -p1

# cmpci driver update
%patch5440 -p1

# raid autorun
%patch5450 -p1

# nfs + O_DIRECT fixes
%patch5460 -p1

#
# NFS over TCP patches

# check that the socket is still connected
%patch5490 -p1
# flow control improvements
%patch5500 -p1

#
# XATTR/ACL patches

# xattr core
%patch5520 -p1
# xattr/ext3
%patch5530 -p1
# xattr syscalls
%patch5540 -p1
# acl core
%patch5550 -p1
# acl/ext3
%patch5560 -p1
# acl/nfs
%patch5570 -p1
# VM changes for acl/xattr
%patch5580 -p1

# NFS lockd v4 granted responses and right blocking semantics
%patch5590 -p1

# place blocking locks that won't expire last on nlm_block list
%patch5600 -p1

# have nfsd honour ACLs on a per-export basis
%patch5610 -p1

# fix nfs over tcp disconnect race condition
%patch5620 -p1

# rework how the nfs client deals with reconnecting to the server
%patch5630 -p1

# ignore acl errors in knfsd, in some corner cases
%patch5640 -p1

# make sure lockd uses reserved ports
%patch5650 -p1

# NFS ACL over the wire protocol extensions
%patch5660 -p1

# fix a race with the scsi timer code
%patch5670 -p1

# ips driver updates
%patch5675 -p1
%patch5676 -p1

# CCISS driver update
%patch5680 -p1

# megaraid driver updates
%patch5690 -p1
%patch5691 -p1
%patch5692 -p1

# fix nfs tcp client corruption bug
%patch5700 -p1

# replace xdr_shift_buf() with 2.5 version, fix potential kmap deadlock
%patch5710 -p1

# ensure that 'unlink' XDR structures are correctly aligned on 64 bit systems
%patch5720 -p1

# update the aic7xxx/aic79xx drivers
%patch5730 -p1 -E
# add iorl to aic7xxx/aic79xx drivers
%patch5731 -p1
# add vary_io to aic7xxx/aic79xx drivers
%patch5732 -p1

# cpqarray driver update to 2.4.26
%patch5740 -p1

# aacraid driver updates
%patch5745 -p1

# autofs upgrade and extra functionality
%patch5750 -p1
%patch5751 -p1

# 3ware driver upgrade, to 1.02.00.033
%patch5760 -p1

# emu10k1 driver fixes
%patch5770 -p1

# ACL support for JFS
%patch5780 -p1

# NFS HA failover support
%patch5790 -p1

# SCSI device list updates
%patch5800 -p1

# LVM does up() from irq context, so make their rwsems irq safe
%patch5810 -p1

# fix ACL/NFSD/ext3/jbd deadlock
%patch5820 -p1
%patch5821 -p1
%patch5822 -p1

# nfsd: only set ->reuse for tcp sockets, not udp
%patch5830 -p1

# nfsd: acl related mount and export flags
%patch5840 -p1

# fix nfs exp_fodrop oops
%patch5850 -p1

# unmap all pages when xdr_kmap() fails
%patch5860 -p1

# cdrom 32 bit compatibility ioctl fixes
%patch5870 -p1

# NFS softirq race fix
%patch5880 -p1

# kNFSd -  Convert error code to nfserror code in nfsd_symlink
%patch5890 -p1

# kNFSd - BKL is missing in once place in knfsd
%patch5900 -p1

# kNFSd/lockd - Blocked lockd not being purged correctly
%patch5910 -p1

# PCI IDs for i810 esb5 sound card
%patch5920 -p1

# net driver fixes and updates
%patch5930 -p1
%patch5931 -p1
%patch5932 -p1
%patch5935 -p1

# bladecenter usb ohci fixes
%patch5940 -p1

# make lockd port configurable with sysctl
%patch5950 -p1

# fix bug in rpc retry code
%patch5960 -p1

# tg3 updates
%patch5970 -p1

# pci_ids.h updates
%patch5980 -p1

# md multipath enablers
%patch5990 -p1

# patch (merged upstream) that works around a VFS limitation and allows
# vxfs filesystems to be exported over NFS
%patch6000 -p1

# hack to read the last sector of a disk on IA64, where the partition
# table could be on the last sector
%patch6010 -p1

# add netdump support to various net drivers
%patch6020 -p1

# unshare file descriptors
%patch6030 -p1

# acl related nfs_get_root bugfix
%patch6040 -p1

# nfs permission bits efficiency patch
%patch6050 -p1

# NFS Solaris 8 acl fix
%patch6060 -p1

# NFS performance enhancements and miscellaneous fixes
%patch6065 -p1
%patch6070 -p1
%patch6080 -p1
%patch6090 -p1

# /proc/tty/driver directory permission restriction
%patch6100 -p1

# ncpfs fixes/updates
%patch6110 -p1

# GFS enablers
%patch6200 -p1

#
# Patches 7000 to 8000 are reserved for scalability fixes
# that touch various subsystems
#

# gendisk statistics scalability
%patch7000 -p1

# make kstat array a per-cpu thing
%patch7010 -p1

# scalable gettimeofday
%patch7020 -p1

# cpu affinity for scsi command processing
# (most of patch has been disabled for performance reasons, but KMI preserved)
%patch7030 -p1

# use softirqs instead of bhs for the scsi layer
%patch7040 -p1

# scsi request lock scalability
%patch7050 -p1

# scsi mid-layer queuing improvements
%patch7055 -p1

# SMP scalable timers
%patch7060 -p1

# slab cache scalability improvements
%patch7070 -p1

# kiobuf fixes and optimisations
%patch7080 -p1
# aio w/ odirect on block devices
%patch7081 -p1

# use seq_file for /proc/interrupts to avoid overflowing the buffer (ppc64)
%patch7090 -p1

# finegrained process accounting
%patch7100 -p1

# readv/writev for raw IO
%patch7110 -p1

# make sure sync(2) terminates in a reasonable time
%patch7120 -p1

# change dentry cache reclaim priority for tux
%patch7130 -p1

# defer softirq processing if stack is too deep
%patch7140 -p1

# s390 on-demand timer patch
%patch7150 -p1


#
# Patches 8000 to 9000 are reserved for new drivers
#
# generic drivers/addon infrastructure
%patch8000 -p1
# (ugly) driver for the Dell megarac remote access cards
%patch8010 -p1
# old wvlan_cs driver
%patch8020 -p1
# ECC reporting module
%patch8030 -p1
# Broadcom 5820 driver
%patch8040 -p1
# add tulip_old driver (2.4.3 version)
%patch8050 -p1
# cipe 1.4.5
%patch8060 -p1
%patch8061 -p1
# LM-Sensors 2.6.5
%patch8070 -p1
# qla2x00 and qla2x00_60600b11
%patch8080 -p1
%patch8081 -p1
# AEP SSL Accelerator card
%patch8090 -p1

#
# Patches to support AES loop device
#
%patch8100 -p1

#
# Soundblaster Live! Audigy driver
#
%patch8110 -p1

# core changes for network channel bonding
%patch8120 -p1
# network channel bonding update
%patch8121 -p1

# Serial ATA
%patch8140 -p1
# Handle taroon-specific driver API (not in 2.4 or 2.5 upstream)
%patch8142 -p1
# ICH6 PATA support
%patch8143 -p1

# mpt fusion 2.05.11.03 and 2.05.05+ backup
%patch8150 -p1
%patch8151 -p1
%patch8152 -p1

# IBM icom modem driver
%patch8160 -p1
# and some code to use a serial debugger over the icom card
%patch8161 -p1

# Oracle hangcheck timer
%patch8170 -p1

# recent (agp 3.0) Intel agpgart support and drm updates
%patch8180 -p1
%patch8181 -p1

# qdio (s390)
%patch8190 -p1

# qeth (s390)
%patch8200 -p1

# zcrypt (s390) - z90 crypt support
%patch8210 -p1

# zfcp (s390) - zSeries fibre channel driver
%patch8220 -p1

# b44
%patch8230 -p1

# ipr (ppc64) - IBM's PPC RAID adapters
%patch8240 -p1

# LAuS syscall auditing support
%patch8250 -p1


#
# final stuff
#

# file offset handling fixes
%patch10000 -p1

# lots of small fixes to warnings and other silly bugs
%patch10010 -p1

# several small tweaks
%patch10020 -p1

# 
# Add MODULE_LICENSE() to the modules missing it
#
%patch10030 -p1

# snip out some luxury code when CONFIG_SMALL is on, for -BOOT kernel
%patch10040 -p1


# END OF PATCH APPLICATIONS

cp %{SOURCE10} Documentation/

mkdir configs

cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-i?86*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-athlon*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-x86_64*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-s390*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64?series.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ia64*.config configs
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ia32e*.config configs
# not used for compilation, but needed for kernel-source rpm 
cp -fv $RPM_SOURCE_DIR/kernel-%{kversion}-ppc64.config configs

# make sure the kernel has the sublevel we know it has...
perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{sublevel}/" Makefile

# get rid of unwanted files
find . -name "*.orig" -exec rm -fv {} \;
find . -name "*~" -exec rm -fv {} \;

###
### build
###
%build

cd linux-%{version}

DependKernel() {
    # is this a special kernel we want to build?
    if [ -n "$2" ] ; then
	Config=$1-$2
	KernelVer=%{version}-%{release}$2
	echo MAKE DEPEND FOR $2 $1 KERNEL...
    else
	Config=$1
	KernelVer=%{version}-%{release}
	echo MAKE DEPEND FOR up $1 KERNEL...
    fi
    make -s mrproper
# We used to copy the config file to arch/.../defconfig, but for some time now
# the Configure script has been smart enough to override this with the
# config file found in configs/kernel-%{kversion}-${config}.config when it
# finds a valid /boot/kernel.h file.  As a result, making an RPM on a
# machine that has a valid kernel.h file will result in scripts/Configure
# overriding our config entries with whatever it thinks is appropriate
# (aka, if you try an i386 build on a machine with an i686 smp kernel.h file
# then you will get an i686 smp kernel in an i386 package).  So, instead we
# put our config file in .config, which is considered the ultimate source
# of default config information by make oldconfig.  Also, copy the config
# files out of the configs directory instead of the RPM_SOURCE_DIR.  It
# doesn't make any sense to put them in there and then not use them,
# especially when we could have a patch that modifies the config files
# as part of the hugemem patch set (or any other patch, it just makes
# us more flexible to use the configs from the configs directory).  Finally,
# since make mrproper wants to wipe out .config files, we move our mrproper
# up before we copy the config files around.
    cp configs/kernel-%{kversion}-$Config.config .config
    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}$2/" Makefile

    # We do make oldconfig twice; otherwise, make oldconfig tends to get stuff
    # wrong in the light of cyclic dependencies

    make -s oldconfig_nonint
    make -s oldconfig_nonint
    make -s scripts/mkdep
    make -s %{?_smp_mflags} dep
    make -s include/linux/version.h 
}

BuildKernel() {
    if [ -n "$1" ] ; then
	Config=%{_target_cpu}-$1
	KernelVer=%{version}-%{release}$1
	DependKernel %{_target_cpu} $1
	echo BUILDING A KERNEL FOR $1 %{_target_cpu}...
    else
	Config=%{_target_cpu}
	KernelVer=%{version}-%{release}
	DependKernel %{_target_cpu}
	echo BUILDING THE NORMAL KERNEL for %{_target_cpu}...
    fi

    make -s %{?_smp_mflags} SPEC_CFLAGS="-g" %{buildtarget}
    make -s %{?_smp_mflags} modules || exit 1

    # first make sure we are not losing any .ver files to make mrproper's
    # removal of zero sized files.
    find include/linux/modules -size 0 | while read file ; do \
	echo > $file
    done
    # Start installing stuff
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 configs/kernel-%{kversion}-$Config.config $RPM_BUILD_ROOT/boot/config-$KernelVer
    cp arch/*/boot/*mage $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-$KernelVer || :
    cp arch/*/boot/*mage.partial $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-partial-$KernelVer || :
    # make sure that we don't strip the partially linked vmlinuz for pSeries
    chmod 644 $RPM_BUILD_ROOT/%{image_install_path}/vmlinuz-partial-$KernelVer || :
    cp vmlinux $RPM_BUILD_ROOT/boot/vmlinux-$KernelVer


    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    make -s INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer

%if ! %xoslinux
#   move the modules in the SOURCE14 file to the unsupported/ directory
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/unsupported
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel ; {
	 tar cf - `cat %{SOURCE14}`  | tar xf - -C ../unsupported
	 rm -rf `cat %{SOURCE14}` 
	 if [ "$1." == "hugemem." ] ; then
		 tar cf - `cat %{SOURCE15}`  | tar xf - -C ../unsupported
		 rm -rf `cat %{SOURCE15}` 
	 fi 
    } ; popd
%endif

#   mark the modules executable
    if [ "$1" != "BOOT" ] ; then
     	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.o" -type f  | xargs chmod u+x
    fi

#   now separate out the debug info from the modules/vmlinux
   /usr/lib/rpm/find-debuginfo.sh %{_builddir}/%{?buildsubdir} || :

#   and compress the modules for space saving
#    if [ "$1" != "BOOT" ] ; then
#    	find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.o" -type f  | xargs gzip -9
#    fi

#   remove files that will be auto generated by depmod at rpm -i time
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.*
#   remove legacy pcmcia symlink that's no longer useful
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/pcmcia


}

SaveHeaders() {
    echo "SAVING HEADERS for $1 $2"
    # deal with the kernel headers that are version specific
    mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1
    install -m 644 include/linux/autoconf.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/autoconf.h
    install -m 644 include/linux/version.h \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/version.h
    mv include/linux/modules \
	$RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/$2/$1/
    echo $2 $1 ../../savedheaders/$2/$1/ >> $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders/list
}

###
# DO it...
###

rm -rf $RPM_BUILD_ROOT

%if %{buildhugemem}
BuildKernel hugemem
SaveHeaders hugemem %{_target_cpu}
%endif

%if %{buildsmp}
BuildKernel smp
SaveHeaders smp %{_target_cpu}
%endif

%if %{buildBOOT}
BuildKernel BOOT
SaveHeaders BOOT %{_target_cpu}
%endif

# UNIPROCESSOR KERNEL
%if %{buildup}
BuildKernel
SaveHeaders up %{_target_cpu}
%endif

%ifarch ppc64
DependKernel ppc64pseries
SaveHeaders ppc64pseries ppc64pseries
DependKernel ppc64iseries
SaveHeaders ppc64iseries ppc64iseries
# we have to run this since we never do an actual build
/usr/lib/rpm/find-debuginfo.sh %{_builddir}/%{?buildsubdir} || :
%endif

#
# i386 is a special case; the kernel source there is supposed
# to also have the modversions/headers/config of i586/i686/athlon
#
%ifarch i386
DependKernel i586
SaveHeaders up i586
DependKernel i686
SaveHeaders up i686
DependKernel athlon
SaveHeaders up athlon
DependKernel i586 smp
SaveHeaders smp i586
DependKernel i686 smp
SaveHeaders smp i686
DependKernel i686 hugemem
SaveHeaders hugemem i686
DependKernel athlon smp
SaveHeaders smp athlon
%endif
%ifarch x86_64
DependKernel ia32e
SaveHeaders ia32e ia32e
%endif



###
### install
###

%install

cd linux-%{version}
mkdir -p $RPM_BUILD_ROOT/{boot,sbin}

for i in `ls -d $RPM_BUILD_ROOT/lib/modules/*`; do
  rm -f $i/build 
  ln -sf ../../../usr/src/linux-%{KVERREL} $i/build
done

# architectures that don't build kernel-source (i586/i686/athlon) are done here
# and can skip the next steps; the source building will do the header magic instead.

%if %{buildsource}

mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
# generated binaries should be removed; we don't want kernel-source to depend on glibc
rm -f drivers/net/hamradio/soundmodem/gentbl scripts/mkdep
# copy the source over
tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
# set the EXTRAVERSION to <version>custom, so that people who follow a kernel
# building howto don't accidentally overwrite their currently working moduleset
perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}custom/" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/Makefile
install -m 644 %{SOURCE10}  $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# clean up the destination
make -s mrproper -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
cp configs/kernel-%{kversion}-%{_target_cpu}.config $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/.config
make -s oldconfig_nonint -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s symlinks -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
make -s include/linux/version.h -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}

# this generates modversions info which we want to include and we may as
# well include the depends stuff as well, after we fix the paths
make -s depend -C $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}
find $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL} -name ".*depend" | \
while read file ; do
    mv $file $file.old
    sed -e "s|[^ ]*\(/usr/src/linux\)|\1|g" < $file.old > $file
    rm -f $file.old
done

# Try to put some smarter autoconf.h and version.h files in place
pushd $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/include/linux ; {
rm -rf modules modversions.h autoconf.h version.h
cat > modversions.h <<EOF
#ifndef _LINUX_MODVERSIONS_H
#define _LINUX_MODVERSIONS_H
#include <linux/rhconfig.h>
#include <linux/modsetver.h>
EOF
echo '#include <linux/rhconfig.h>' > autoconf.h
list=`find ../../savedheaders/* -name '*.ver' -exec basename '{}' \; | sort`
mkdir modules
for l in $list; do
    sed 's,$,modules/'$l, ../../savedheaders/list | awk -f %{SOURCE13} > modules/$l
    touch -r modules/$l modules/`basename $l .ver`.stamp
    echo '#include <linux/modules/'$l'>' >> modversions.h
done
echo '#endif' >> modversions.h
sed 's,$,autoconf.h,' ../../savedheaders/list | awk -f %{SOURCE12} >> autoconf.h
install -m 644 %{SOURCE11} rhconfig.h
echo "#include <linux/rhconfig.h>" >> version.h
keyword=if
for i in smp BOOT hugemem up ppc64pseries ppc64iseries; do
# When we build in an i386, we don't have an hugemem header directory
# in savedheaders/i386/hugemem.  We also don't have a BOOT directory
# anywhere except in savedheaders/i386.  So, we need to use this method
# of determining if a kernel version string needs to be included in the
# version.h file
    verh=`echo ../../savedheaders/*/$i/version.h | awk ' { print $1 } '`
    if [ -n "$verh" -a -f "$verh" ]; then
	if [ "$i" = up ]; then
	    if [ "$keyword" = if ]; then
		echo "#if 0" >> version.h
	    fi
  	    echo "#else" >> version.h
	else
	    echo "#$keyword defined(__module__$i)" >> version.h
	    keyword=elif
	fi
	grep UTS_RELEASE $verh >> version.h
    fi
done
echo "#endif" >> version.h
if [ -f ../../savedheaders/%{_target_cpu}/up/version.h ] ; then
    # keep to a standard normally
    HEADER_FILE=../../savedheaders/%{_target_cpu}/up/version.h
else
    # test build not including uniprocessor, must get info from somewhere
    HEADER_FILE=$(ls ../../savedheaders/%{_target_cpu}*/*/version.h | head -n 1)
fi
grep -v UTS_RELEASE $HEADER_FILE >> version.h
rm -rf ../../savedheaders
} ; popd
touch $RPM_BUILD_ROOT/boot/kernel.h-%{kversion}

for i in $RPM_BUILD_ROOT/lib/modules/*; do
  rm -f $i/modules.*
done

%endif
rm -rf $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/savedheaders

# fix up the tmp_include_depends file wrt the buildroot path
perl -p -i -e "s|$RPM_BUILD_ROOT||g" $RPM_BUILD_ROOT/usr/src/linux-%{KVERREL}/tmp_include_depends

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

# do this for upgrades...in case the old modules get removed we have
# loopback in the kernel so that mkinitrd will work.
%pre 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :

%pre smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :

%pre hugemem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :

%post 
cd /boot
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}
exit 0

%post smp
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}smp
exit 0

%post hugemem
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}hugemem
exit 0

%post BOOT
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade
[ -x /sbin/mkkerneldoth ] && /sbin/mkkerneldoth
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --mkinitrd --depmod --install %{KVERREL}BOOT
exit 0

%if ! %xoslinux

%post unsupported
[ -x /sbin/depmod -a -e /boot/System.map-%{KVERREL} ] && \
    /sbin/depmod -ae -F /boot/System.map-%{KVERREL} %{KVERREL}
exit 0

%post smp-unsupported
[ -x /sbin/depmod -a -e /boot/System.map-%{KVERREL}smp ] && \
    /sbin/depmod -ae -F /boot/System.map-%{KVERREL}smp %{KVERREL}smp
exit 0

%post hugemem-unsupported
[ -x /sbin/depmod -a -e /boot/System.map-%{KVERREL}hugemem ] && \
    /sbin/depmod -ae -F /boot/System.map-%{KVERREL}hugemem %{KVERREL}hugemem
exit 0

%endif

# Allow clean removal of modules directory
%preun 
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}
exit 0

%preun smp
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}smp
exit 0

%preun hugemem
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}hugemem
exit 0

%preun BOOT
/sbin/modprobe loop 2> /dev/null > /dev/null  || :
[ -x /sbin/new-kernel-pkg ] && /sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}BOOT
exit 0

# We need this here because we don't prereq kudzu; it could be
# installed after the kernel during an OS upgrade
%triggerin -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin smp -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin hugemem -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

%triggerin BOOT -- kudzu
[ -x /usr/sbin/module_upgrade ] && /usr/sbin/module_upgrade || :

# Old kernel-headers packages owned include symlinks; new
# ones just make them so that we can have multiple kernel-headers
# packages installed.

%triggerpostun source -- kernel-headers < 2.2.16
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}
exit 0

%post source
cd /usr/src
rm -f %{kslnk}
ln -snf linux-%{KVERREL} %{kslnk}

%postun source
#
# fix up the /usr/src/linux-2.4 symlink to point to another kernel-source dir if possible
#
if [ -L /usr/src/%{kslnk} ]; then 
    if [ -L /usr/src/%{kslnk} -a `ls -ld /usr/src/%{kslnk} 2>/dev/null| awk '{ print $11 }'` = "linux-%{KVERREL}" ]; then
	[ $1 = 0 ] && rm -f /usr/src/%{kslnk}
    fi
fi
exit 0

###
### file lists
###

%if %{buildup}
%files 
%defattr(-,root,root)
/boot/vmlinux-%{KVERREL}
/%{image_install_path}/vmlinu*-%{KVERREL}
/boot/System.map-%{KVERREL}
/boot/config-%{KVERREL}
%dir /lib/modules
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/kernel
/lib/modules/%{KVERREL}/build

%if ! %xoslinux
%files unsupported
%defattr(-,root,root)
%dir /lib/modules/%{KVERREL}
/lib/modules/%{KVERREL}/unsupported
%endif

%endif

%if %{buildsmp}
%files smp
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}smp
/boot/System.map-%{KVERREL}smp
/boot/config-%{KVERREL}smp
%dir /lib/modules
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/kernel
/lib/modules/%{KVERREL}smp/build

%if ! %xoslinux
%files smp-unsupported
%defattr(-,root,root)
%dir /lib/modules/%{KVERREL}smp
/lib/modules/%{KVERREL}smp/unsupported
%endif
%endif

%if %{buildhugemem}
%files hugemem
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}hugemem
/boot/System.map-%{KVERREL}hugemem
/boot/config-%{KVERREL}hugemem
%dir /lib/modules
%dir /lib/modules/%{KVERREL}hugemem
/lib/modules/%{KVERREL}hugemem/kernel
/lib/modules/%{KVERREL}hugemem/build

%if ! %xoslinux
%files hugemem-unsupported
%defattr(-,root,root)
%dir /lib/modules/%{KVERREL}hugemem
/lib/modules/%{KVERREL}hugemem/unsupported
%endif
%endif

%if %{buildBOOT}
%files BOOT
%defattr(-,root,root)
/boot/vmlinu?-%{KVERREL}BOOT
/boot/System.map-%{KVERREL}BOOT
/boot/config-%{KVERREL}BOOT
%dir /lib/modules
%dir /lib/modules/%{KVERREL}BOOT
/lib/modules/%{KVERREL}BOOT/kernel
/lib/modules/%{KVERREL}BOOT/build
%endif

# only some architectures need kernel-source and kernel-doc

%if %{buildsource}

%files source
%defattr(-,root,root)
%dir /usr/src/linux-%{KVERREL}
/usr/src/linux-%{KVERREL}/COPYING*
/usr/src/linux-%{KVERREL}/CREDITS
/usr/src/linux-%{KVERREL}/Documentation
/usr/src/linux-%{KVERREL}/MAINTAINERS
/usr/src/linux-%{KVERREL}/Makefile
/usr/src/linux-%{KVERREL}/README
/usr/src/linux-%{KVERREL}/REPORTING-BUGS
/usr/src/linux-%{KVERREL}/Rules.make
/usr/src/linux-%{KVERREL}/arch
/usr/src/linux-%{KVERREL}/drivers
/usr/src/linux-%{KVERREL}/crypto
/usr/src/linux-%{KVERREL}/fs
/usr/src/linux-%{KVERREL}/init
/usr/src/linux-%{KVERREL}/ipc
/usr/src/linux-%{KVERREL}/kernel
/usr/src/linux-%{KVERREL}/lib
/usr/src/linux-%{KVERREL}/mm
/usr/src/linux-%{KVERREL}/net
/usr/src/linux-%{KVERREL}/scripts
/usr/src/linux-%{KVERREL}/configs
/usr/src/linux-%{KVERREL}/include
/usr/src/linux-%{KVERREL}/tmp_include_depends
/usr/src/linux-%{KVERREL}/.depend
/usr/src/linux-%{KVERREL}/.hdepend

%files doc
%defattr(-,root,root)
%doc linux-%{version}/Documentation/*

%endif

%changelog
* Fri Aug 20 2004 X/OS Linux Team <xoslinux@xos.nl> 2.4.21-15.0.4.EL.XOS.1
- Build for X/OS Linux 3.0.
- X/OS Linux source rpm based on kernel-2.4.21-15.0.4.EL.src.rpm
  (md5sum of original source rpm: 9f04fbd5d2b5182bfe7fa0242b4fd0a3).
- Do not split up drivers (unsupported subpackages) for X/OS Linux.

* Fri Jul 30 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.0.4.EL
- fix hang w/SoundBlaster 16-bit sampling w/odd count (Ernie Petrides)
- fix ia64 unwind handling for UNW_INSN_SETNAT_MEMSTK (Jason Baron)
- set QLogic HbaApiNode proc file permissions to 0600 (Tom Coughlan)
- fix possible races/overflows in file offset handling (Alexander Viro)
- fix e1000 data leakage with SIOCETHTOOL/ETHTOOL_GREGS (Ernie Petrides)

* Tue Jun 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.0.3.EL
- add owner check in inode_change_ok() for gid changes (Ernie Petrides)

* Wed Jun 16 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.0.2.EL
- fix user-space access bugs in acpi/airo/decnet/sound (Alexander Viro)
- fix mm_struct mem leak in copy_process() error path (Ernie Petrides)

* Tue Jun 15 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.0.1.EL
- prevent FPU exception handling hangs on x86/x86_64 (Ernie Petrides)

* Wed Apr 21 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-15.EL
- fix clobbering of /proc/cpuinfo vendor_id on x86_64 (Jim Paradis)
- correct MCAST_MSFILTER/IP_MSFILTER size checking (Ernie Petrides)

* Wed Apr 14 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-14.EL
- disable linux-2.4.21-ppc64-pte-hash-lock.patch (Julie DeWandel)
- prevent symlink buffer overflow in ISO-9660 fs (Ernie Petrides)
- check for skb overrun in IPV4/IPV6 IGMP handling (Dave Miller)
- fix possible hang in rebalance_laundry_zone() (Larry Woodman)
- correct zone_wired[] initialization for NUMA (Jim Paradis)

* Wed Apr  7 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-13.EL
- fix several critical libata bugs (Jeff Garzik)
- correct IPSEC XFRM policy ref counting (Dave Miller)
- add amd64/ia32e parsing for "acpi=off" arg (Jim Paradis)
- update tg3 driver to v3.1 for several fixes (Dave Miller)
- fix SCSI whitelist for Hitachi/HP DFx00, Apple Xserve (Tom Coughlan)

* Fri Mar 26 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-12.EL
- add USB support for Handspring Treo 600 PDA syncing (Matthew Galgoci)
- clear state for CPEs during ia64 MCA SAL error logging (Ben Woodard)
- prevent DMA resource leak in QLogic driver error path (Tom Coughlan)
- change default QLogic driver device queue depth to 64 (Tom Coughlan)
- replace fabricated cciss drive geometry w/ENXIO error (Tom Coughlan)
- update SCSI whitelist for HP SureStore/StorageWorks (Tom Coughlan)
- disable CONFIG_ACPI_DEBUG in amd64/ia32e configs (Jim Paradis)

* Mon Mar  8 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-11.EL
- add yet another Intel ICH6 SATA PCI id (Jeff Garzik)
- fix ref counting in copy_process() error path (Larry Woodman)
- remove ia64 support for /proc/bus/mckinley/bitmap (Jason Baron)
- correct depmod versioning for unsupported modules (Ernie Petrides)
- prevent data corruption in ia32e phys_proc_id[] info (Larry Woodman)
- change default value for inactive_clean_percent to 30 (Larry Woodman)
- enable improved version of s390 on-demand timer patch (Pete Zaitcev)

* Tue Mar  2 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-10.EL
- incorporate late-breaking libata fixes (Jeff Garzik)
- enable amd64 syscall for tux support (Ingo Molnar)

* Mon Mar  1 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.17.EL
- reduce s390 idle overhead with on-demand timer patch (Pete Zaitcev)
- complete ia64 NPTL support for 32-bit-EL executables (Jason Baron)
- add several ia64 syscall table entries for 32-bit-EL (Jason Baron)
- upgrade libata/SATA support, delete ich5-sata.patch (Jeff Garzik)
- check for mremap/vmtruncate race in move_one_page() (Jason Baron)
- prevent ia64 NaT-bit corruption during sig catching (Jason Baron)
- fix amd64 get_mtrr() parsing error with >4GB memory (Jim Paradis)
- change amd64 default behavior to avoid TSC timer use (Jim Paradis)
- force s390utils upgrade to prevent zipl seg fault (Ernie Petrides)

* Sun Feb 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.16.EL
- restore varyio capability in mptfusion driver update (Adam Manthei)
- enhance SCSI mid-layer queuing for indefinite retries (Doug Ledford)
- add ia64 reg reloads for 32-bit-EL strace -f support (Jason Baron)
- fix ia64 core dump support for 32-bit-EL executables (Jason Baron)
- add SCSI whitelist devs with BLIST_RETRY_ABORTED_CMD (Doug Ledford)
- remove stack-in-interpreter check in binfmt_elf.c (Julie DeWandel)
- clear all flags in exec_usermodehelper() for kmod (Alexander Viro)
- fix aacraid command completion (rq corruption) bugs (Tom Coughlan)
- correct cciss_proc_tape_report() type in flags decl (Tom Coughlan)
- enable USB-2.0-hub-based mice/keyboards to function (Pete Zaitcev)

* Sat Feb 28 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.15.EL
- fix amd64 oprofile linkage problem in ia32e support (Ernie Petrides)
- update ips driver to version 6.11.07 w/6.10.52 backup (Tom Coughlan)
- add size checks to DRM ATI r128 driver ioctl handling (John Dennis)
- avoid megaraid2 irq_disable calls for mem-mapped ctlrs (Tom Coughlan)
- upgrade firmware imbedded in QLogic driver to 3.02.24 (Tom Coughlan)
- correct ia64 memory accounting in overcommit mode 2 (Larry Woodman)
- implement softirq deferral to limit kernel stack depth (Ingo Molnar)
- reduce kernel stack usage in a couple of tux functions (Ingo Molnar)
- fix shared extended attribute ref counting in ext3 (Stephen Tweedie)
- clear SCSI sense data buffer between eh retries (Doug Ledford)

* Thu Feb 26 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.14.EL
- add .RH1 suffix to cciss driver version v2.4.50 (Tom Coughlan)
- implement initial LAuS syscall auditing support (Mark DeWandel)
- introduce GFS enablers for locking and sendfile ops (Ken Preslan)
- update QLogic driver to 6.07.01 w/6.06.00b11 backup (Tom Coughlan)
- improve netdump reliability w/asynchronous IPI param (Jeff Moyer)
- add ICH6 DSP audio support to i810_audio driver (Jeff Garzik)
- apply SCSI whitelist updates for several devices (Tom Coughlan)
- fix odd byte tape i/o handling in sym53c8xx driver (Tom Coughlan)
- correct minimum nfsd version that supports acls (Steve Dickson)

* Wed Feb 25 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.13.EL
- allow concurrent NFS direct i/o to same file if !append (Steve Dickson)
- introduce support for new Intel 64-bit ia32e processor (Larry Woodman)
- update mptfusion driver to 2.05.11.03 w/2.05.05 backup (Adam Manthei)
- remove fs/binfmt_misc.o from linux-modules-unsupported (Jason Baron)
- fix ia64 predicate register use in sig trampoline code (Jason Baron)
- add oprofile cpu type recognition for ia32e processor (Will Cohen)
- update e1000 network driver to version 5.2.30.1-k1 (Jeff Garzik)
- add more Intel PCI ids to match upstream 2.4 (Jeff Garzik)
- add ICH6 PATA support, PCI ids, irq routing (Jeff Garzik)

* Mon Feb 23 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.12.EL
- add deferred page freeing for intr-context unmap_kvec() (Jeff Moyer)
- update megaraid2 driver to v2.10.1.1 w/v2.00.9 backup (Tom Coughlan)
- fix ppc64 pte hash table locking to avoid deadlocks (Julie DeWandel)
- fix ia64 data TLB init to prevent random boot-up hangs (Jason Baron)
- fix ia64 RNat register corruption with alt sig stacks (Jason Baron)
- allow smaller ia64 sig stacks in ia32 emulation layer (Jason Baron)
- backport ncpfs fixes to eliminate var-length arrays (Jeff Moyer)

* Fri Feb 20 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.11.EL
- backport cisco aironet driver from 2.6.3-rc4 (Matthew Galgoci)
- update tg3 driver to v2.7 to fix status reg handling (Dave Miller)
- correct lost jiffies logic for x440/5 cyclone timer (Bernd Schmidt)
- fix open() error clean-up for unsupported O_DIRECT (Stephen Tweedie)
- prevent ia64 crashes when unmapping hugetlb pages (Jason Baron)
- add ppc64 processor support for future PPC970+ (Julie DeWandel)
- rework ppc64 32-bit-compat iptables support (Julie DeWandel)
- fix func ptr test in ethtool_set_ringparam() (Jeff Garzik)
- disable linux-2.4.21-scsi-affine-queue.patch (Doug Ledford)
- improve scsi_allow_ghost_devices description (Doug Ledford)

* Wed Feb 18 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.10.EL
- fix amd64 iommu bug causing data corruption on >4GB systems (Jim Paradis)
- return EINVAL for unsupported ioctl32 syscalls on ppc64 (Julie DeWandel)
- remove incorrect BUG() call in __remove_inode_page() (Stephen Tweedie)
- fix s390 ctc driver problem causing build system hangs (Pete Zaitcev)
- fix s390 qeth driver error path to reset write_busy (Pete Zaitcev)
- update s390 zfcp driver to fix miscellaneous bugs (Pete Zaitcev)
- apply upstream nfs fixes for acl error handling (Steve Dickson)
- prevent kernel stack data leak via /dev/rtc (Ernie Petrides)
- allow AIO operations on sockets for non-inet (Dave Miller)

* Mon Feb 16 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.9.EL
- restore genksyms_smp_prefix setting for non-x86 builds (Ernie Petrides)
- display/log memory stats whenever there's an OOM kill (Larry Woodman)
- update tg3 driver to v2.6, the latest upstream version (Jeff Garzik)
- update net bonding driver to v2.4.1, latest upstream (Jeff Garzik)
- fix irq, mem, printk, strtol bugs in cciss driver (Tom Coughlan)
- wait for board ready after hot add, cciss driver (Tom Coughlan)
- enable cciss adapter prefetch for x86 platforms (Tom Coughlan)
- add preserve_arg0 handling for ia32 emulation (Larry Woodman)
- fix ppc64 compat support for quota syscall (Julie DeWandel)

* Thu Feb 12 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.8.EL
- remove Power-Blade-specific def for USB TEAC floppy (Julie DeWandel)
- fix s390 crash in iucv driver on connection shutdown (Pete Zaitcev)
- fix ia64 ACPI parsing for multinode IDE devs on x455 (Jim Paradis)
- fix amd64 core dumping of multithreaded 32-bit apps (Jim Paradis)
- fix s390 oprofile conditional and zero top addr bits (Will Cohen)
- add ipr driver v1.0.3 for IBM's PPC RAID adapters (Tom Coughlan)
- add {alloc,free}_netdev(), list macro, tg3 PCI ids (Jeff Garzik)

* Tue Feb 10 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.7.EL
- restrict /proc/tty/driver directory access to root (Jeff Moyer)
- allow non-standard usr/sys VM splits at 2G/2G, 1G/3G (Ingo Molnar)
- extend existing ppc64 RTAS firmware flash interface (Mark DeWandel)
- fix ppc64 version of strncpy() to zero-pad buffers (Julie DeWandel)
- fix s390/x version of strncpy() to zero-pad buffers (Pete Zaitcev)
- fix generic version of strncpy() to zero-pad buffers (Jim Paradis)
- improve ppc64 segment table entry replacement logic (Julie DeWandel)
- correct type/cast of "len" in ppc64/kernel/nvram.c (Julie DeWandel)
- implement new ppc64 RTAS system call interface (Julie DeWandel)
- increase x86 RSDT table limit in ACPI parsing (Jim Paradis)

* Mon Feb  9 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.6.EL
- fix more usb-storage bugs for Power Blade support (Julie DeWandel)
- remove extra inactive_clean_pages-- in reclaim_page() (Larry Woodman)
- return proper error codes for do_munmap() failure in mremap (Dave Jones)
- fix binfmt_elf.c problems for apps with huge bss regions (Julie DeWandel)
- update cciss driver to v2.4.50 for Smart Array 6i support (Tom Coughlan)

* Thu Feb  5 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.5.EL
- prevent netdump progress output from filling up log_buf (Jeff Moyer)
- add ppc64 RAS hook at end of panic() processing (Julie DeWandel)
- correct source IP address in ICMP error message (Dave Miller)
- fix smp deadlock with pdeath_signal posting (Roland McGrath)
- add ppc64 support for /proc/ppc64/lparcfg (Julie DeWandel)

* Wed Feb  4 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.4.EL
- update nfsd mode-with-acls fix for upstream conformance (Steve Dickson)
- rework usb-storage locking to avoid hangs on disconnect (Pete Zaitcev)
- fix mmio alignment error in olympic token ring driver (Julie DeWandel)
- prevent tux logger-thread shutdown problems on ppc64 (Ingo Molnar)
- add ppc64 AltiVec chip support for Power Blades (Julie DeWandel)
- eliminate multi-threaded coredump hang potential (Ingo Molnar)
- fix ppc64 segfaults with tasks > 2GB in size (Julie DeWandel)
- fix usb-storage memory-allocation/iowait deadlock (Alan Cox)

* Mon Feb  2 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.3.EL
- add amd64 support for PT_GNU_STACK with exec shield (Jim Paradis)
- fix s390 raid1 sync problem w/writes at end of dev (Pete Zaitcev)
- update s390 zcrypt driver to version 1.1.4 (Pete Zaitcev)
- fix output of large /proc/pid/statm values (Mark DeWandel)
- fix output of large /proc/partitions values (Mark DeWandel)
- enable ppc64 support for JS20 Power Blades (Julie DeWandel)
- fix kernel stack memory leak on fork failures (Dave Anderson)
- fix ipv6 packet quoting problem in icmpv6_send() (Dave Miller)

* Thu Jan 29 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.2.EL
- apply Intel's x86 microcode loader update (Jim Paradis)
- enhance PCI multifunction support for ppc64 (Julie DeWandel)
- fix nfsd returning bad mode bits when acls set (Steve Dickson)
- prevent unkillable zombies from detached NPTL threads (Ingo Molnar)
- avoid missing scsi disks in /proc/partitions on detach (Jason Baron)
- correct pte calculation inside zeromap_pte_range() loop (Ben Woodard)
- add inline function PDE() to help driver backporting (Matthew Galgoci)

* Wed Jan 21 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.1.EL
- (this is the first build for RHEL 3 Update 2)
- relocate various pieces of the "undo" patch (Patch Review Committee)
- rename s390 zcrypt and zfcp driver patches (Pete Zaitcev)
- add LKML discussion to COPYING.modules (Arjan van de Ven)

* Thu Jan  8 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-9.EL
- fix race condition between thread creation and signals (Ingo Molnar)

* Wed Jan  7 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-8.EL
- fix amd64 eflags masking in 32-bit emulation of ptrace (Jim Paradis)

* Tue Jan  6 2004 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-7.EL
- fix numerous ppc64 problems with /proc access (Julie DeWandel)
- allow user core files larger than 2GB in size (Dave Anderson)
- add ia64 support for Crestone Peak AGP bridges (John Dennis)
- fix unaligned kernel accesses in nfs_readdir() (Steve Dickson)
- add new_len/new_addr checks in do_mremap() (Ernie Petrides)
- fix nfs O_DIRECT corruption with >4GB files (Steve Dickson)
- enable bus scan for AGP ctlrs on amd64 systems (John Dennis)
- limit PCI-alloc'ed physaddrs to 4GB on HP ia64 (Jason Baron)

* Mon Dec  8 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-6.EL
- fix ppc64 firmware updates (Julie DeWandel)
- fix sync wakeup problem (Ingo Molnar)
- add ia64 cyclone support (Jason Baron)

* Mon Dec  1 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-5.EL
- undo rejected patches (Stephen Tweedie, Arjan van de Ven, Rik van Riel)

* Wed Nov 26 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.20.EL
- enable NUMA support in amd64 smp configs (Jim Paradis)
- prevent oopses with tux in OOM scenarios (Ingo Molnar)
- apply several ipv6 multicast bug fixes (Dave Miller)
- assign retval in copy_process() error path (Ingo Molnar)
- add lseek-in-/proc support for s390x "ps" (Pete Zaitcev)
- redefine zone_is_highmem() for Celestica (Dave Anderson)
- fix unresolved symbols in amd64 modules (Bill Nottingham)

* Tue Nov 25 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.19.EL
- fix tg3 rx_pending limit for BCM5705/BCM5782 chips (Jeff Garzik)
- reset page error flag prior to read of new contents (Jeff Moyer)
- enable CONFIG_HOTPLUG_PCI option for ia64 configs (Doug Ledford)
- fix inactive laundry list race in ramfs_writepage() (Dave Anderson)
- avoid out_of_memory() for wired pages when there's lomem (Dave Anderson)
- conditionalize ppc64 machdep_calls change for KMI compat (Ernie Petrides)
- limit anon/cache pages scanned in refill_inactive_zone() (Larry Woodman)

* Mon Nov 24 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.18.EL
- create old version (rev. 5.64) of cmpci sound driver (Tom Coughlan)
- remove ac97.o, ad1848.o, cs4232.o from unsupported (Jeff Moyer)

* Mon Nov 17 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.17.EL
- fix missing use of __GFP_HIGHMEM flag in pte_alloc_one() (Larry Woodman)

* Sat Nov 15 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.16.EL
- rework scsi mid-layer queuing logic to fix error handling (Doug Ledford)
- fix pci_dma_sync_sg() scatterlist arg in megaraid2 driver (Tom Coughlan)
- move more-ptes-in-rmap-pte-chain logic to its own patch (Ernie Petrides)
- tag uses of __GENKSYMS__ with KMI/ABI compat comment (Ernie Petrides)

* Fri Nov 14 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.15.EL
- fix MD multipath bugs causing crashes during fail-overs (Doug Ledford)
- add chain_ptep_t and revert pte_addr_t for KMI compat (Ernie Petrides)
- restore sub-timer-tick time-of-day granularity for ia64 (Jason Baron)
- modify agpgart and drm drivers for ia64 HP ZX1 support (John Dennis)
- fix ia64 32-bit emulation for several stat-related calls (Jason Baron)
- enable amd64 use of new ips driver w/config separation (Tom Coughlan)
- update e100 network driver to version 2.3.30-k1 (Jeff Garzik)
- update e1000 network driver to version 5.2.20-k1 (Jeff Garzik)
- apply scsi whitelist updates for IBM/CNSi/NEC devices (Tom Coughlan)
- reenable varyio for aic7xxx driver (hangs were unrelated) (Jeff Moyer)
- conditionalize NVIDIA_NFORCE3 to restore KMI compat (Ernie Petrides)
- prevent two ext3 panics on corrupted filesystems (Stephen Tweedie)
- apply two minor fixes to ppc64 RAS nvram reading (Julie DeWandel)

* Thu Nov 13 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.14.EL
- update ServeRAID (ips) driver to version 6.10.52 (Tom Coughlan)
- configure xmon on by default in ppc64 configs (Julie DeWandel)
- create initial s390 zcrypt driver, version 1.1.2 (Pete Zaitcev)
- remove zfcp driver from linux-modules-unsupported (Pete Zaitcev)
- revise ppc64 reliability/serviceability support (Julie DeWandel)
- reduce kernel stack usage inside nfs_readdir() (Steve Dickson)
- add gameport dependency to cmpci driver config (Tom Coughlan)

* Wed Nov 12 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.13.EL
- reduce UDP retransmissions and fix slow reads for NFS (Steve Dickson)
- implement wired page lists for better ramfs handling (Larry Woodman)
- fix vfork deadlock when child process causes core dump (Ingo Molnar)
- enhance AltSysRq-M output and fix deadlock potential (Larry Woodman)
- update cmpci sound driver for some HP IPF workstations (Tom Coughlan)
- correct tq_struct struct initialization in tg3 driver (Jeff Garzik)
- fix NFS file attribute inconsistency after rename (Steve Dickson)
- prevent ia64 machine checks w/sysreport on Olympia (Larry Woodman)

* Tue Nov 11 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.12.EL
- redesign refill_inactive_zone() for smarter deactivation (Larry Woodman)
- improve page deactivation scalability w/delayed laundering (Larry Woodman)
- rework locking and timer usage in s390 ctc network driver (Pete Zaitcev)
- allow xmon to be enabled at boot-time for ppc64 debugging (Julie DeWandel)
- reverse kscand's order of anon/cache active list traversal (Larry Woodman)
- force in-lining of br_read/write_lock/unlock routines (Julie DeWandel)
- fix mistaken fall-through cases in s390 chandev driver (Pete Zaitcev)
- make a few exported symbols available to OpenGFS (Stephen Tweedie)
- fix ld/st ordering bug causing lost signal wakeups (Mark DeWandel)

* Thu Nov  6 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.11.EL
- make profile=X imply nmi_watchdog=1 and fix NMI w/d bugs (Ernie Petrides)
- add lock init in scsi_get_host_dev() to fix shutdown hang (Doug Ledford)
- enable distributed interrupts by default on ppc64 iSeries (Julie DeWandel)
- improve amd64 reporting of machine check errors (Jim Paradis)
- fix disabling of autonegotiation in tg3 driver (Dave Miller)
- add image name to s390 ioctl32 debug message (Pete Zaitcev)

* Wed Nov  5 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.10.EL
- fix file lock ownership by NPTL threads to be process-wide (Ernie Petrides)
- upgrade megaraid driver to version 1.18k and fix isr/fw sync (Tom Coughlan)
- upgrade megaraid2 driver to version 2.00.9 and enable varyio (Tom Coughlan)
- improve scsi mlqueue handling to enable BUSY/QUEUE_FULL fix (Doug Ledford)
- correct reporting of i/o errors in ppc64 viodasd driver (Julie DeWandel)
- update acenic driver to handle enabling of jumbo frame mode (Jeff Moyer)
- fix i386 PAGE_NONE bits to prevent get_user_page() hang (Roland McGrath)
- fix ia64 show_mem() handler to use efi_memmap_walk() call (Dave Anderson)
- replace spaces in slabinfo entry name for async poll table (Matt Wilson)
- fix race condition in buffer-head memory footprint patch (Larry Woodman)

* Tue Nov  4 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.9.EL
- improve spec file robustness in %post/%preun stanzas (Florian La Roche)
- add s390x iovec length checking for 32-bit reads/writes (Matt Wilson)
- use highmem for pte/ramfs page allocation w/__GFP_WIRED (Larry Woodman)
- upgrade oprofile support with bug fixes and enhancements (Will Cohen)
- fix infinite recursion in SCSI mid-layer post-processing (Jeff Moyer)
- introduce no-auto-start-on-add handling for SCSI blacklist (Jeff Moyer)
- enable s390 support for blk stats handling for iostat -x (Pete Zaitcev)
- fix LVS timer-related hang from ip_vs_conn_expire() bug (Ernie Petrides)
- correct module init in cpqarray driver to fix insmod crash (Tom Coughlan)
- incorporate ESB PATA support and fix a pirq_routers PCI id (Jeff Garzik)
- fix nfs async write deadlock potential w/nfs_writepage() (Steve Dickson)
- fix SCSI error handling for BUSY queue status messages (Doug Ledford)
- improve ppc64 32-bit ioctl support for use by ethtool (Julie DeWandel)
- add missing unlock in ip_mc_del_src() to fix IGMP deadlock (Dave Miller)
- change ppc64 reporting of floppy capacity to be 1.44 MB (Julie DeWandel)

* Wed Oct 29 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.8.EL
- fix up various problems on Nforce3-based amd64 systems (Jim Paradis)
- double number of pte addrs in rmap pte_chain structs (Larry Woodman)
- restrict slab size for kernel data structs to 2 pages (Larry Woodman)
- clean up obsolete quicklist usage for ppc64 pte pages [rejected]
- prevent readdirplus from returning hidden mount points (Steve Dickson)
- prevent lockd deadlocks caused by export table locking (Steve Dickson)
- eliminate use of parallel task_struct init macro on ia64 [rejected]
- fix broken s390x overflow checks with 32-bit F_GETLK use (Matt Wilson)
- fix SCSI errors with "mt stoptions" and IDE tape drives (Pete Zaitcev)

* Sun Oct 26 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.7.EL
- fix bad checksumming interaction between e100 and bridge (Jeff Garzik)
- prevent system hang by OOM killing when overcommitted (Larry Woodman)
- un-inline ext3 error function to reduce stack usage (Stephen Tweedie)
- fix several ppc64 problems with interrupt handling (Julie DeWandel)
- correct amd64 identification in /dev/oprofile/cpu_type (Jim Paradis)
- move fput() call in do_tty_hangup() to avoid oops w/kon (Alexander Viro)
- eliminate creation of never-used task_struct slab cache (Larry Woodman)

* Thu Oct 23 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.6.EL
- reduce buffer-head memory footprint from read-only files (Ingo Molnar)
- update qeth driver for reduced stack usage and bug fixes (Pete Zaitcev)
- fix s390 qeth driver again to allow tcpdump to function (Pete Zaitcev)
- add exec_mmap() locking to prevent vma lookup races (Ernie Petrides)
- rework RPC slot allocation for further NFS improvements (Steve Dickson)
- reduce frequency of RPC retransmits during NFS writes (Steve Dickson)
- make generic/ext3 file system write handling 64-bit clean (Jeff Moyer)
- allow SMP scheduling rebalancing to occur every 200 msecs (Ingo Molnar)
- prevent races during IPC semaphore set and msg queue removal (Ingo Molnar)
- fix ACPI handling to identify trigger/polarity of PCI IRQs (Jim Paradis)
- correct amd64/ia64 acpi_disabled decls for post-boot access (Jeff Moyer)
- update ppc64 viocons driver with several bug fixes (Julie DeWandel)

* Thu Oct 16 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.5.EL
- move fix for PPR use in sym53c8xx driver to its own patch (Ernie Petrides)
- correct pids exported by msgctl/semctl/shmctl/fcntl calls (Ulrich Drepper)
- apply s390 lcs driver wait queue init and locking updates (Pete Zaitcev)
- enable dummy network driver use in generic s390 config file (Pete Zaitcev)
- add missing ptrace hooks for exec and vfork-done events (Bill Nottingham)
- fix SMP timer race that triggered BUG_ON() in add_timer() (Ingo Molnar)
- fix several bogus ipvs boundary checks in ftp module [rejected]
- fix vfsmount queuing in attach_mnt() for CLONE_NEWNS [rejected]
- add net_device check to prevent oops in pppoe driver [rejected]
- fix memory leak in symlink error path of /proc driver [rejected]
- fix overflow in v1_disk2mem_dqblk() quota calculation [rejected]
- increase ppc64 ramdisk size to 8192k in p/iSeries configs (Jeremy Katz)
- lower amd64 TASK_UNMAPPED_32 to increase avail address space (Jim Paradis)

* Mon Oct 13 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.4.EL
- fix ppc64 stack pointer alignment in user signal handlers (Jakub Jelinek)
- increase amd64 exception stack size to 4k to avoid overflow (Jim Paradis)
- fix ppc64 interrupt rate accounting for vmstat and /proc (Julie DeWandel)
- extend amd64 NMI watchdog timeouts to tolerate bad 2nd cpu (Jim Paradis)
- allow s390 dasd driver to use noop elevator module (Pete Zaitcev)
- add free_irq() in error path of olympic token ring driver (Matt Wilson)

* Sat Oct 11 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.3.EL
- make pid fields in ucred structures hold tgid values (Ulrich Drepper)
- prevent ppc64 iSeries virtual console writes > 4k (Julie DeWandel)
- control ia64 unaligned access messages with new sysctl (Jeff Moyer)
- correct SCSI data direction on cmd to spin up disks (Pete Zaitcev)
- add do_brk() TASK_SIZE and address space wrap checks (Arjan van de Ven)
- limit PPR use in sym53c8xx driver for ppc64 Zapata drives (Doug Ledford)
- list ac97.o, ad1848.o, and cs4232.o modules as unsupported (Jeff Moyer)
- clean up conditional compilation in s390 zfcp driver (Pete Zaitcev)

* Thu Oct  9 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.2.EL
- identify whether i686 or athlon config in oops output (Arjan van de Ven)
- remove warning in reclaim_page() unmapped page path (Ernie Petrides)
- fix several lvm error handling paths causing memory leaks [rejected]
- correct i386 smp shutdown logic when netdump is enabled (Jeff Moyer)
- fix amd64 potential data leaks on FPU save/restore errors (Jim Paradis)
- prevent aic7xxx chip resets leading to PCI parity errors (Tom Coughlan)
- remove ia64 user tty warning on unaligned accesses (Arjan van de Ven)
- fix ppc64 /proc file buf overruns in viodasd driver (Mark DeWandel)

* Wed Oct  8 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.1.EL
- (this is the first build for RHEL 3 Update 1)
- avoid m/ctime update for pipe writes on r/o file systems (Stephen Tweedie)
- prevent theoretical ext3 fs corruption in ext3_read_inode (Stephen Tweedie)
- enable AGRESSIVE_IDLE_STEAL to improve scheduler balancing (Ingo Molnar)
- fix potential ppc64 lock-up on ioctl32 un/reregistering (Pete Zaitcev)

* Fri Oct  3 2003 Ernie Petrides <petrides@redhat.com> kernel-2.4.21-4.EL
- extend ppc64 scsi timeout values for Zapata DVD-ROM drives (Julie DeWandel)

* Fri Sep 19 2003 Rik van Riel <riel@redhat.com> kernel-2.4.21-3.EL
- make sure to release viotape op structure after use (Julie DeWandel)
- disable pgd/pmd quicklists on ppc64 (Mark DeWandel)
- temporarily disable aio on sockets (Jeff Moyer)
- correctly refile inodes to make them reclaimable (Harald Hoyer)

* Wed Sep 17 2003 Rik van Riel <riel@redhat.com> kernel-2.4.21-2.EL
- S390: update zfcp and cio drivers (Pete Zaitcev)
- IA64: add extra check to virtual mem_map (Larry Woodman, Dave Anderson)
- initialise local variables in ide-tape & ide-scsi
- cap qla2200 tcq depth to 255
- switch version number scheme to kernel-2.4.21-N.EL

* Tue Sep 16 2003 Rik van Riel <riel@redhat.com>
- PPC64: invalidate evicted sbl entries in the erat (Julie DeWandel)
- increase ethernet tx_queue_len to 1000 (David Miller)
- in udp_{v6_}flush_pending_frames, reset up->len too (David Miller)
- S390: CMS reserved minidisk detection (Pete Zaitcev)
- call recount_segments() on a different occasion (Pete Zaitcev)

* Mon Sep 15 2003 Rik van Riel <riel@redhat.com>
- really disable exec-shield (Roland McGrath)
- reduce stack randomisation, disable brk randomisation (Ingo Molnar)
- make e1000 driver 64 bit clean (Julie DeWandel)
- minor aio corner case error condition fix (Jeff Moyer)
- AMD64: more lenient check for call workaround (Ernie Petrides)
- PPC64: disable CONFIG_XMON (Mark DeWandel)
- S390: fix CCW slab selection (Pete Zaitcev)
- fix two-disk combined mode sata (Jeff Garzik)
- move buslogic scsi driver to supported, for vmware only (Tom Coughlan)
- change viocons message from KERN_WARNING to KERN_INFO (Julie DeWandel)

* Fri Sep 12 2003 Rik van Riel <riel@redhat.com>
- VM: handle race condition in reclaim_page (Stephen Tweedie, Larry Woodman)
- PPC64: fix "log_buffer broken" xmon issue (Julie DeWandel)
- fix compiler warnings in netdump (Jeff Moyer)
- AMD64: workaround for 32 bit compat mode page fault problem (Ernie Petrides)
- IA64: make perfmon root-only (Jason Baron)

* Thu Sep 11 2003 Rik van Riel <riel@redhat.com>
- fix smp race in rebalance_laundry_zone()

* Wed Sep 10 2003 Rik van Riel <riel@redhat.com>
- fix compiler warnings when hugetlbfs is disabled (Pete Zaitcev)
- fix tux performance bug (Ingo Molnar)

* Tue Sep  9 2003 Rik van Riel <riel@redhat.com>
- don't evict kernel stack seg translation on ppc64 (Julie DeWandel)
- fix callers of do_page_fault on ppc64 (Mark DeWandel)
- AMD64 munmap return value, fix lsb failure (Jeff Moyer)
- fix for PPC64 32-bit ioctl (Jim Paradis)
- bring IA64 value of MINSIGSTKSZ in line with upstream (Jakub Jelinek)

* Mon Sep  8 2003 Rik van Riel <riel@redhat.com>
- fix potential datacorruptor in viodasd driver (Julie DeWandel)
- fix race condition in s390 dirty bit handling (Pete Zaitcev)
- limit per-cpu slab cache size
- correct 32-bit readv/writev border cases on ppc64 (Matt Wilson)
- AMD Golem IO-APIC fixup for i686 kernel on AMD64 (Jeremy Katz)
- NFS Solaris 8 acl fix (Steve Dickson)

* Fri Sep  5 2003 Rik van Riel <riel@redhat.com>
- minor nfs permissions bugfix (Steve Dickson)
- change mprotect return value to SuS mandated value (Arjan van de Ven)
- kernel-unsupported now provides kernel-modules (Jeremy Katz)
- correct __hugemem__modules typos in rhkernel.h
- fix subtle pmd corruption error (Larry Woodman, Dave Anderson)
- fix cut'n'paste error in SATA io port reservation
- restore NFSEXP_CROSSMNT ABI compatibility (Steve Dickson)
- round up executable name field length in core file (Jakub Jelinek)
- switch off exception_trace on amd64 (Jeff Moyer)

* Tue Sep  2 2003 Rik van Riel <riel@redhat.com>
- patch to access odd last sector on ia64 (Jason Baron)
- misc fixes from upstream (Arjan van de Ven)
- fix audigy driver (Jeff Garzik)
- tunable dcache reclaim priority for tux (Ingo Molnar)
- tg3 driver update (Jeff Garzik)
- ipv6 and icmp network bugfixes (David Miller)
- fix ppc64 memory access security bug (Julie DeWandel)
- reduce memory allocated for skb (Ingo Molnar)
- small smp fix for scalable timers (Ingo Molnar)
- make s390 recognise MSDOS partitions (Pete Zaitcev)
- small smp fixes in tux (Ingo Molnar)
- make mptfusion drivers supported on 4/4 split kernel (Tom Coughlan)
- add entries to scsi whitelist (Tom Coughlan)
- minor sata/ata driver updates (Jeff Garzik)
- small fixes to viodasd driver (Julie DeWandel)
- nfs_get_root and nfs access bit patches (Steve Dickson)

* Thu Aug 28 2003 Rik van Riel <riel@redhat.com>
- don't show interrupts in /proc/stat for ppc64 (Matt Wilson)
- make sure sync returns in a reasonable time
- PPC64: fix for boot cpu not being cpu 0 (Julie DeWandel)
- zero sized write no longer updates mtime (Matt Wilson)
- fix video bios read corruption on ia64 (Larry Woodman)
- network fixes to tg3, bonding (Jeff Garzik)
- properly reserve legacy IDE regions in sata driver (Jeff Garzik)
- fix ppc64 signal handling bugs (Mark DeWandel)
- tux fixes (Ingo Molnar)
- tgkill syscall for s390(x) (Pete Zaitcev)
- amd64 32 bit compatibility fixes (Jim Paradis)
- ppc64 32 bit compatibility fixes (Julie DeWandel)
- fix 4G/4G follow_page problem (Ingo Molnar)
- reduce memory used by VMAs and dentries (Arjan van de Ven)
- make LVM snapshotting of ext3 work reliably (Stephen Tweedie)
- make netdump play better with the nmi watchdog (Jeff Moyer)
- QLA2200: disable irq mitigation, fix off-by-one (Arjan van de Ven)

* Mon Aug 25 2003 Rik van Riel <riel@redhat.com>
- seq_file /proc/interrupts for x86 too (Ingo Molnar)
- fix memory leak in ia64 exec of ia32 binaries
- check tgid not pid in scm_check_creds()  (David Miller)
- VM fixes: shm swap priority, zeromap_page_range
- workaround VFS limitations for VXFS NFS export

* Fri Aug 22 2003 Rik van Riel <riel@redhat.com>
- use personality for 3GB userspace on x86 -hugemem (Ingo Molnar)
- add sysctl interface for lockd (Steve Dickson)
- don't prod VGA space on HP Pinnacle systems (Larry Woodman)
- fix for 32 bit binaries on amd64 (Jim Paradis)
- add preemption point to write_some_buffers (Julie DeWandel)
- sort ACPI table to get correct device ordering on HP (Larry Woodman)
- fix refcounting bug with ipv6 addresses on netdevs (David Miller)
- add s390 syscalls for tux (Pete Zaitcev)
- md multipath enablers (Doug Ledford)

* Thu Aug 21 2003 Rik van Riel <riel@redhat.com>
- fix process and nice time accounting (Doug Ledford)
- amd64: syscall table updates, timer robustness (Jim Paradis)
- amd64 3GB personality for 32-bit processes (Jim Paradis)
- use 256MB pagesize for hugetlbfs on ia64 (Larry Woodman)
- make sure e100 only claims ipv4 checksumming
- igmpv3/mldv2 OOPS'er fix (David Miller)
- hugetlbfs: make chown work and allow uid=X,gid=Y mount options
- make larger mmap windows work (Ernie Petrides, Ingo Molnar)
- ia64: improve ia32 compatibility (Larry Woodman)
- fix bug in rpc retry code (Steve Dickson)
- make acpi pci hotplug modulable (Jeff Moyer)
- update (trivial) to megaraid 1.18j (Tom Coughlan) 
- enable varyio on mptfusion (Tom Coughlan)
- panic on oops to prevent data corruption opportunities (Ernie Petrides)
- small iorl locking fix (Doug Ledford)
- fix ppc64 get_wchan() bad deref (Mark DeWandel)
- fix aio read into mmap()d PROT_WRITE (Jeff Moyer, Ernie Petrides)

* Wed Aug 20 2003 Rik van Riel <riel@redhat.com>
- libata update (Jeff Garzik)
- amd64 syscalls for xattrs & ACLs (Jim Paradis)
- tux fixes (Julie DeWandel, Ingo Molnar)
- via & i810 audio fixes (Jeff Garzik)
- small 4G/4G split bugfixes (Ingo Molnar)
- fix sigsuspend race on x86, amd64, ia64 (Mark DeWandel)
- ia32 behavior for FP denormal exceptions on ia64 (Jason Baron)
- get the set/get of NAT bits for ia64 correct (Jason Baron)
- ipsec update, adds cast6 encryption (David Miller)
- VM update: OOM bugfix & page->flags atomic updates (Rik van Riel)
- reenable serpent encryption on ppc64
- bladecenter usb-ohci support (Pete Zaitcev)
- iorl fixes (Doug Ledford)
- network bonding driver oops fix (Jeff Garzik)

* Wed Aug 13 2003 Rik van Riel <riel@redhat.com>
- DAC960 back to bigmem supported, ne2k-pci & usb audio to bigmem unsupported
- netdump updates for tg3 and e1000 (Jeff Moyer)
- put a hole between stack and mmap area (Ernie Petrides)
- process time accounting updates (Doug Ledford)
- fix null characters in TUX header (Julie DeWandel, Ingo Molnar)
- display correct executable when running interpreted script
- zfcp zSeries fibrechannel driver (Pete Zaitcev)
- ipsec updates (David Miller)
- fix 4G/4G race conditions (Ingo Molnar)
- rename -bigmem kernel to -hugemem to reflect changed tradeoffs
- optionally show task states from hangcheck timer (Jason Baron)
- various small bugfixes from upstream

* Sat Aug  9 2003 Rik van Riel <riel@redhat.com>
- fix scalable timer race condition  (Julie DeWandel, Ingo Molnar)
- print warning on boot with >16GB RAM on -smp kernel (Arjan van de Ven)
- fix for xapic issue with ServerWorks chipsets (Ernie Petrides)
- remove spurious ioctl printk on ppc64 (Mark DeWandel)
- ppc64 wchan improvement (Mark DeWandel)
- hint @pause changes for ia64
- longer scsi scan timeout on ppc64 (Julie DeWandel)
- readv/writev for raw IO (Stephen Tweedie)
- fix for easy stack/mmap collisions (Ernie Petrides)

* Thu Aug  6 2003 Rik van Riel <riel@redhat.com>
- various XAPIC related fixes (Ingo Molnar)
- correct context switch and iowait stats with HT shared runqueues
- ext3 obscure deadlock fixes (Stephen Tweedie)
- knfsd fixes: blocked lock, symlink error & missing bkl  (Steve Dickson)

* Wed Aug  5 2003 Rik van Riel <riel@redhat.com>
- de_thread bugfix from 2.6 upstream  (Matt Wilson)
- viocons driver update (Julie DeWandel)
- fix VM non-overcommit mode (Rik van Riel)

* Tue Aug  4 2003 Rik van Riel <riel@redhat.com>
- plug data leak in aio code (Jeff Moyer)
- initial list of 4G/4G unsupported modules (Tom Coughlan)
- nfs softirq race fix (Steve Dickson)
- updated IPSEC patch (David Miller)
- networking updates/fixes from 2.4.22-preX (David Miller)

* Sun Aug  3 2003 Rik van Riel <riel@redhat.com>
- drop orlov allocator for now (Arjan van de Ven)
- correct HT cpu pair detection (Arjan van de Ven)
- build zImage.partial for netbooting on pSeries (Matt Wilson)
- fix missing symbols

* Sat Aug  2 2003 Rik van Riel <riel@redhat.com>
- export two AIO symbols for OCFS
- disable CONFIG_DEBUG_SLAB so performance testing can start
- crosshost mmap hooks for distributed filesystems (Stephen Tweedie)
- include partially linked zImage for pSeries netboot (Matt Wilson)
- nfs highmem fix, unmap when xdr_kmap() fails (Steve Dickson)
- update megaraid2 locking to work with IORL (Com Coughlan)
- make sure to build the qla2100 driver (Tom Coughlan)
- fix cdrom ioctl 32 bit compatibility for ppc64, amd64 (Julie DeWandel)

* Thu Jul 31 2003 Rik van Riel <riel@redhat.com>
- run depmod on install of unsupported modules (Arjan van de Ven)
- fix register corruption in IA64 lazy fpu handling (Larry Woodman)
- add b44 network driver (Jeff Garzik)
- make ppc64 pci interface routines compatible (Julie DeWandel)
- allow 32 bit userland on AMD64 and PPC64 to use volumes > 2GB (Jeff Moyer)
- nfsd: acl related mount and export flags (Steve Dickson)
- fix nfs exp_fodrop oops (Steve Dickson)
- fix missed signal wakeups on ppc64 (Mark DeWandel)
- smp scalable timer bugfixes (Ingo Molnar)
- workaround for a prefetch bug in some Athlon CPUs (Ernie Petrides)
- code to make more modules unsupported for 4/4 split (Arjan van de Ven)
- various spec file and config cleanups
- viopath driver fix (Julie DeWandel)
- add match for 440gx chipset bioses (Arjan van de Ven)
- move epic100 and ne2k-pci back to supported (Jeff Garzik)

* Tue Jul 29 2003 Rik van Riel <riel@redhat.com>
- updated finegrained process accounting patch (Doug Ledford)
- make iSeries compile without CONFIG_ICOM (Julie DeWandel)
- nfsd: only set ->reuse for tcp sockets, not udp  (Steve Dickson)
- enable the 4G/4G split on the i686-bigmem kernel only
- sysrq support for viocons (Julie DeWandel)
- limit pci_bus size changes to ppc64 (Jeff Garzik)
- fix for signal delivery race (Ernie Petrides, Mark DeWandel)
- add ShdPnd to /proc (Ingo Molnar)
- fix de_thread() hang (Ingo Molnar)
- add kernel support for CLONE_STOPPED (Ernie Petrides)
- make sure to initialise HVC console (Julie DeWandel)
- fix _SEG abort hit in ACPI code (Larry Woodman)
- build addon drivers on amd64 and ppc64 too (Tom Coughlan)
- build IPS driver on all architectures (Tom Coughlan)
- fix a few ia32 emulation bugs for IA64 (Larry Woodman)
- enable correct/new __clear_bit macro for IA64 (Larry Woodman)
- flexible mmap allows mappings of huge executable segments (Larry Woodman)
- sysrq-w for s390 (Pete Zaitcev)

* Thu Jul 17 2003 Rik van Riel <riel@redhat.com>
- have s390 cpu_relax() also include barrier  (Pete Zaitcev)
- convert ppc64 xmon traceback code to ksymoops (Matt Wilson)
- rename kstat_sum() variable with aliasing problems  (Ingo Molnar)
- fix AIO-on-hugetlbfs crash (Ingo Molnar)
- update support for IA64 Long's Peak ACPI serial ports  (Larry Woodman)
- turn on xmon for both iSeries and pSeries (Matt Wilson)
- bugfix to make CLI work correctly on iSeries (Julie DeWandel)
- SATA bugfixes (Jeff Garzik)
- enable 4G/4G split in -BOOT kernel, due to syslinux trouble

* Wed Jul 16 2003 Rik van Riel <riel@redhat.com>
- fix s390 compile (Pete Zaitcev)
- taint the kernel on sii6512 driver link, GPL but no source available
- handle debug registers with 4G/4G split (Ingo Molnar)
- tgkill syscall for ppc64 (Julie DeWandel)
- fix NFSD/ACL/ext3/jbd deadlock (Stephen Tweedie, Steve Dickson)
- fix maxcpus=1 installation panic fix for ppc64 (Julie DeWandel)
- IDE byteswapping io functions for ppc64 (Julie DeWandel)
- update sata driver (Jeff Garzik)
- raise the number of /proc entries (Julie DeWandel)
- sticky sysrq key with timeout (Jeff Moyer)

* Tue Jul 15 2003 Rik van Riel <riel@redhat.com>
- make SysRq-W useable on s390 (Pete Zaitcev)
- updated process accounting patch (Doug Ledford)
- siginfo_t fixes for s390x and amd64 (Jakub Jelinek)
- clustered NFS fail-over support (Steve Dickson)
- autofs4 updates and fixes
- ia64 patches to reduce cpu power/temp in idle loop (Larry Woodman)
- add irqsafe up() for LVM locking (Stephen Tweedie)
- O_DIRECT fallback to synchronous allocation in holes (Stephen Tweedie)

* Mon Jul 14 2003 Rik van Riel <riel@redhat.com>
- ia64 HP iommu: add sx1000 detection
- possible bug in s390x 32-bit emulation  (Roland McGrath)
- updated ipsec patch, should fix all current ipv6 bugs  (David Miller)
- finegrained process accounting (Doug Ledford)
- ICH5 pci irq routing, and associated ids (Jeff Garzik)
- fix the machine_real_restart() reboot path on 4G/4G (Ingo Molnar)

* Fri Jul 11 2003 Rik van Riel <riel@redhat.com>
- fix amd64 agp-gart code to work around hugetlbfs debug code (Jim Paradis)
- fix ppc32 pthread_cancel (Jakub Jelinek) 
- Do not sent IGMP leave messages unless IFF_UP  (David Miller)
- software iommu for ia64 systems without hardware iommu (Jason Baron)
- fix ext3 oops fix during dio, LTP failure (Arjan van de Ven, Stephen Tweedie)

* Thu Jul 10 2003 Pete Zaitcev <zaitcev@redhat.com>
- Remove illegal calls to dst_link_failure

* Thu Jul 10 2003 Rik van Riel <riel@redhat.com>
- enable HT scheduler for bigmem kernel
- add tgkill syscall for x86 and ia64
- make -BOOT kernel smaller w/ modular md and CONFIG_SMALL
- rmap VM updates
- 4G/4G agpgart potential corruption fix (Larry Woodman)

* Wed Jul  9 2003 Rik van Riel <riel@redhat.com>
- switch off exec shield everywhere
- eliminate hostfs for amd64 (Jim Paradis)
- megaraid update, mostly vendor ID (Tom Coughlan)
- shrink boot kernel by disabling some config options
- additions for the SCSI whitelist (Tom Coughlan)
- ia64 extable fix (Jason Baron)
- viocons driver upgrade (Julie DeWandel)
- another ia64 mmu context wraparound deadlock fix (Larry Woodman)
- iSeries icom debugger patch (Julie DeWandel)

* Tue Jul 8 2003 Pete Zaitcev <zaitcev@redhat.com>
- Drop io_request_lock in usb scsiglue.c:device_reset

* Tue Jul  8 2003 Rik van Riel <riel@redhat.com>
- fix cpu_relax for amd64 and ia64 to include a barrier (Ingo Molnar)
- restore o_direct api compatibility (Stephen Tweedie)
- fix possible ext3 deadlock in o_direct patches (Stephen Tweedie)
- ACLs for JFS (Stephen Tweedie)
- fix /proc/cpuinfo runqueue printing (Ingo Molnar)
- via audio fixes, smaller emu10k1 patch (Alan Cox, Matt Wilson)

* Mon Jul  7 2003 Rik van Riel <riel@redhat.com>
- fix process accounting, tux ftp passwords and si_pid (Ingo Molnar)
- 32bit compat statfs fix (Guy Streeter)
- don't serialise exit on BKL when accounting is off (Ingo Molnar)
- truncate timeouts to 32 bits on 64bit systems (Ingo Molnar)
- fix network channel bonding (Jeff Garzik)
- split netdump patch into core and net-drivers (Jeff Garzik)
- delayed tlb flushing for ia64 (Larry Woodman)
- emu10k1 driver fixes
- kksymoops for AMD64 (Jim Paradis)
- select bugfixes from 2.4 upstream (Jeff Garzik)
- OOM tweaks (Rik van Riel)
- use seq_file for /proc/interrupts on ppc64 (Mark DeWandel)

* Wed Jul  2 2003 Rik van Riel <riel@redhat.com>
- add qdio and qeth drivers for s390(x)  (Phil Knirsch)
- slab cache scale bugfix (Larry Woodman)
- S390: qdio & qeth drivers (Phil Knirsch)
- hangcheck timer for ppc64 (Julie DeWandel)
- fix race conditions in ia64 ia32 compat layer (Larry Woodman)
- update megaraid, aic7xxx, cciss and cpqarray drivers (Tom Coughlan)
- nfs xdr_shift_buf, tcp client corruption and alignment (Steve Dickson)
- rhconfig.h stuff for ppc64, s390 and s390x (Matt Wilson)
- AIO on sockets

* Tue Jul  1 2003 Rik van Riel <riel@redhat.com>
- kiobuf optimisations (Stephen Tweedie, Larry Woodman)
- ipsec update (David Miller)
- ipvs update to deal with timer changes (David Miller)
- 4G/4G split patch optimisations (Ingo Molnar)
- hangcheck timer (Jason Baron)
- recent (AGP 3.0) agpgart support (Jeff Garzik)

* Mon Jun 30 2003 Rik van Riel <riel@redhat.com>
- semtimedop() support on s390/s390x  (Ernie Petrides)
- fix a 4G bug that triggers on systems with >30 CPUs (Ingo Molnar)
- updated SCSI SMP affine queueing patch  (Arjan van de Ven)
- page hash prefetch in do_generic_file_read bugfix (Julie DeWandel)
- updates the qlogic driver to the latest (Arjan van de Ven)
- slab cache SMP scalability tweaks (Ingo Molnar)
- ACPI 2.0 for IPF and AMD64 (Jim Paradis, Larry Woodman)
- statm fixes for hugetlbfs and remap_file_pages (Jason Baron)
- acpi serial port detection (Larry Woodman)

* Fri Jun 27 2003 Rik van Riel <riel@redhat.com>
- iseries driver updates (Julie DeWandel)
- aio scalability and 2.5 backports  (Ingo Molnar)
- SMP scalable timers (Ingo Molnar)

* Thu Jun 26 2003 Rik van Riel <riel@redhat.com>
- make qlogic driver use new scsi infrastructure (Arjan van de Ven)
- export aio kvec functions
- fix statm oops
- compile fixes 
- NFS ACL over the wire protocol extensions (Steve Dickson)
- rate limit slab pruning, to limit IPI load on SMP systems (Stephen Tweedie)

* Tue Jun 24 2003 Rik van Riel <riel@redhat.com>
- scsi request lock scaling (Ingo Molnar)
- cpu affinity for scsi command processing (Ingo Molnar)
- use softirqs instead of bhs for the scsi layer (Doug Ledford)
- igmpv3 fixes and improvements (David Miller)
- oprofile for ppc64 (Will Cohen)
- Increase MAX_ADDR_LEN from 8 to 32 for Infiniband over IP (Tom Coughlan)

* Mon Jun 23 2003 Rik van Riel <riel@redhat.com>
- per-cpu kstat arrays (Ingo Molnar)
- optimise 4G/4G tlb flushing (Ingo Molnar)
- kiobuf reclaim together with buffer reclaim (Arjan van de Ven)
- more scalable gendisk statistics (Ingo Molnar)
- nfs reconnect fixes (Steve Dickson)
- add 32-bit compatibility for ustat system call on ppc64 (Julie DeWandel)
- scalable gettimeofday (Ingo Molnar)
- hugetlbfs ppc64 & s390 bits (Mark DeWandel, Pete Zaitcev)
- hugetlbfs for ia64 (Jason Baron)
- qlogic scsi driver update (Arjan van de Ven)

* Sat Jun 21 2003 Rik van Riel <riel@redhat.com>
- nfs patches (Steve Dickson)
- xapic improvements, summit support (Ingo Molnar)
- fix core dump name for multithreaded programs (Roland McGrath)

* Fri Jun 20 2003 Rik van Riel <riel@redhat.com>
- merge up to marcelo's latest

* Thu Jun 19 2003 Rik van Riel <riel@redhat.com>
- oom killer fixes (Larry Woodman, Rik van Riel)
- tunable VM overcommit (Rik van Riel)
- hugetlbfs for amd64 (Jim Paradis)

* Wed Jun 18 2003 Rik van Riel <riel@redhat.com>
- updated iseries virtual drivers (Julie DeWandel)
- nfs lockd improvements (Steve Dickson)
- remap_file_pages improvements (Ingo Molnar)
- /proc/efi/symtab patch for ia64 (Larry Woodman)
- disable O_PROFILE on UP x86 machines
- allow NMI watchdog profiling frequencies up to 10kHz (Ingo Molnar)
- statm (Jason Baron)
- hugetlbfs (Ingo Molnar)
- have nfsd honour ACLs on a per-export basis (Steve Dickson)

* Tue Jun 17 2003 Rik van Riel <riel@redhat.com>
- Enable O_PROFILE on non-SMP configs (Stephen Tweedie)
- more conservative AIC config options
- Fix BOOT kernel panic while mounting /dev/cdrom (Larry Woodman)

* Mon Jun 16 2003 Rik van Riel <riel@redhat.com>
- merge to 2.4.21 + selected ac bits
- ipsec upgrade (David Miller)
- HT scheduler patch fix (correct sibling counting)
- make bdflush writeout smoother
- AMD64 gdb fix (Roland McGrath)

* Thu Jun 12 2003 Rik van Riel <riel@redhat.com>
- don't include unsupported drivers in -BOOT kernel
- merge up to 2.4.21-rc8 + selected ac bits
- FIXME: sysrq for 3170, dasd, odirect & odirect for nfs

* Thu Jun 12 2003 Pete Zaitcev <zaitcev@redhat.com
- oprofile for s390

* Tue Jun 10 2003 Rik van Riel <riel@redhat.com>
- statm (Jason Baron / Julie DeWandel)
- AIO 32-bit compat for 64-bit machines (Julie DeWandel)
- only do bufferhead reclaim in extreme situations (Rik van Riel)

* Mon Jun  9 2003 Rik van Riel <riel@redhat.com>
- Serial ATA support (Jeff Garzik)
- mtp fusion 2.05.05+ (Dave Maley)

* Fri Jun  6 2003 Rik van Riel <riel@redhat.com>
- XATTR/ACL patches, except NFS over the wire (Stephen Tweedie)
- ipsec module autoloading (David Miller)
- remap_file_pages (Ingo Molnar)

* Thu Jun  5 2003 Rik van Riel <riel@redhat.com>
- upgrade to latest -rmap with Ernie's fixes
- sysrq+C shows the stack dump of all CPUs
- ext3 truncate fix (Stephen Tweedie)
- NFS fixes for HZ=1000 machines (Steve Dickson)

* Wed Jun  4 2003 Rik van Riel <riel@redhat.com>
- 4G/4G split fix (Ingo Molnar)
- ppc64 fixes (Guy Streeter, Rik van Riel)
- enable oprofile on amd64
- ipsec updates (David Miller)
- fork returns pid instead of task_struct* (Julie DeWandel)
- ia64 ptrace bugfixes (Dave Anderson)

* Tue Jun  3 2003 Rik van Riel <riel@redhat.com>
- HP diva serial driver (Jeff Garzik)

* Mon Jun  2 2003 Rik van Riel <riel@redhat.com>
- NFS over TCP patches (Steve Dickson)
- switch to using ppc64pseries/ppc64iseries arches instead of
  kernel-pseries and kernel-iseries (Jeremy Katz)
- egenera scsi bus rescan patch (Jeff Garzik)
- oprofile (Graydon Hoare)

* Fri May 30 2003 Rik van Riel <riel@redhat.com>
- futex requeue (Ingo Molnar)
- enable NAPI for E1000
- signal latency and scheduler improvements (Ingo Molnar)

* Thu May 29 2003 Rik van Riel <riel@redhat.com>
- kscand oops fix (Ingo Molnar, Rik van Riel)
- pcnet32 fixes (Julie Dewandel)
- raid autorun (Pete Zaitcev)
- turn off CONFIG_SUNDANCE_MMIO (Jeff Garzik)
- flexible mmap (Larry Woodman)
- ppc64 fixes (Matt Wilson, Guy Streeter)
- loop softirq 10 times before giving up (Ingo Molnar)
- O_DIRECT for NFS (Steve Dickson)
- prevent md from shutting down active arrays (Doug Ledford)
- rmap updates, inode reclaim & higher order allocations (Rik van Riel)
- network channel bonding (Jeff Garzik)

* Wed May 28 2003 Jim Paradis <jparadis@redhat.com>
- Re-enable x86_64 in build
- x86_64-specific updates for exec-shield
- Bring in improved "nonx" support for x86_64 from upstream

* Wed May 28 2003 Pete Zaitcev <zaitcev@redhat.com>
- Hush s390 printks upon user SIGSEGV by default. It can be enabled back with
  a sysctl kernel.userprocess_debug.
- Enable optional 3270 console mode on s390.

* Fri May 23 2003 Rik van Riel <riel@redhat.com>
- get rid of vsyscall page (Arjan van de Ven)
- fix missing symbol copy_str_fromuser_size

* Tue May 20 2003 Rik van Riel <riel@redhat.com>
- exec-shield updates to fix hang-on-boot on some systems (Ingo Molnar)
- temporarily disabled the architectures, which got broken by exec-shield updates
- fix for LTP sigprocmask02 failure (Matt Wilson)
- ppc64 updates (Julie DeWandel)

* Mon May 19 2003 Rik van Riel <riel@redhat.com>
- pagecache scalability patch (Ingo Molnar)
- IPC semaphore scalability patch (Ingo Molnar)
- ppc64 updates (Guy Streeter)

* Thu May 15 2003 Rik van Riel <riel@redhat.com>
- exec-shield (Ingo Molnar)
- AMD64 ACPI updates (Jim Paradis)

* Wed May 14 2003 Rik van Riel <riel@redhat.com>
- reenable O_DIRECT, O_DIRECT fixes and superbh-aio (Stephen Tweedie)

* Tue May 13 2003 Rik van Riel <riel@redhat.com>
- vma merging (Stephen Tweedie)

* Mon May 12 2003 Rik van Riel <riel@redhat.com>
- nmi profiler
- VM updates: rmap, dma zone isolation
- tux (Ingo Molnar)
- ext3 stall fixes (Ingo Molnar)
- e1000 fixes (Ingo Molnar)

* Fri May  9 2003 Rik van Riel <riel@redhat.com>
- config files overhaul (Arjan van de Ven)
- fix bug in mlock patch
- IPVS (Dave Miller)

* Thu May  8 2003 Rik van Riel <riel@redhat.com>
- import IO elevator changes from gingin
- critical VM fix
- matrox framebuffer patch for pseries (Julie DeWandel)

* Wed May  7 2003 Rik van Riel <riel@redhat.com>
- hammer nptl fixes (Ulrich Drepper)
- 4G/4G split (Ingo Molnar)

* Tue May  6 2003 Rik van Riel <riel@redhat.com>
- upgrade to 2.4.21-rc1-ac4 (minus -ac acpi and xapic changes)
- drop nfs patches since those seem to be in -ac

* Mon May  5 2003 Rik van Riel <riel@redhat.com>
- larger message buffer size + boot option (Mark DeWandel)
- AMD64: tls handling, coredump fixes (Jim Paradis)
- SMP & highmem VM fixes (Ben LaHaise)
- HT+NUMA scheduler (Ingo Molnar)

* Sat May  3 2003 Rik van Riel <riel@redhat.com>
- ext3 orphan cleanup fix (Ernie Petrides)
- s390 affinity fixes (Pete Zaitcev)
- i386 vsyscall DSO changes (Roland McGrath)

* Fri May  2 2003 Rik van Riel <riel@redhat.com>
- bugfixes and config changes galore

* Thu May  1 2003 Rik van Riel <riel@redhat.com>
- enable semtimedop for other architectures (Ernie Petrides)
- large pci bus numbers (Julie DeWandel)
- bugfixes galore

* Tue Apr 29 2003 Rik van Riel <riel@redhat.com>
- igmpv3 (David Miller) 

* Mon Apr 28 2003 Rik van Riel <riel@redhat.com>
- generic 32bit compat stuff + amd64/ppc64/ipf pieces (Matt Wilson)
- clustered apic (XAPIC) support (Ingo Molnar)
- ppc64 architecture updates (Matt Wilson, Guy Streeter)

* Fri Apr 25 2003 Rik van Riel <riel@redhat.com>
- ppc64 fixes

* Thu Apr 24 2003 Rik van Riel <riel@redhat.com>
- collapse ipsec into one patch (David Miller)
- ppc64 build fix (Matt Wilson)
- improve smp scheduler fairness (Ingo Molnar)
- allow mlock for normal users, up to ulimit (Ingo Molnar)
- AMD64 port (Jim Paradis)

* Wed Apr 23 2003 Rik van Riel <riel@redhat.com>
- clean up mechanism to pass extra CFLAGS so we don't override what's
  already there
- merge ia64 build stuff (Larry Woodman)
- merge varyio + superbh (Stephen Tweedie)

* Tue Apr 22 2003 Rik van Riel <riel@redhat.com>
- merge up to 2.4.21-rc1
- IA64: virtual mem_map, acpi updates, netdump update, pte-highmem & fealnx
- IA64: architecture specific patches

* Mon Apr 21 2003 Rik van Riel <riel@redhat.com>
- import davem's ipsec patch pile
- ppc64 kallsyms and dump_fpu patches (Matt Wilson)
- rmap updates (x86_64 & bufferhead reclaim)
- ppc64 ptrace patch (Matt Wilson)

* Fri Apr 18 2003 Rik van Riel <riel@redhat.com>
- open up patch namespace 2000-5000 for network protocol changes
- renumber existing patches in that range

* Thu Apr 17 2003 Rik van Riel <riel@redhat.com>
- make sure to actually apply the rmap-updates patch
- iowait statistics
- ppc64 code merge (Mark & Julie DeWandel)
- ppc64 build scripts (Matt Wilson)
- raise symlink recursion level to 8 (Ernie Petrides)

* Wed Apr 16 2003 Rik van Riel <riel@redhat.com>
- merge up to marcelo's latest
- pte-highmem bits for x86-64 and ppc64

* Tue Apr 15 2003 Rik van Riel <riel@redhat.com>
- merge up to 2.4.21-pre7-ac1
- drop semtimedop patches (now in -ac)
- drop nfs xprt_fixes, fix_softirq, d_drop and nfs-readeof (merged in -pre7)
- add !CONFIG_QUOTA compile fix for 2.4.21-pre7-ac1

* Mon Apr 14 2003 Pete Zaitcev <zaitcev@redhat.com>
- add LCS driver (endemic to s390)

* Mon Apr 14 2003 Rik van Riel <riel@redhat.com>
- add rmap VM
- add kunmap_atomic debugging patch

* Sat Apr 12 2003 Rik van Riel <riel@redhat.com>
- remove dir.c part of NFS kmap_atomic patch for now
- using strlen as local variable name in nfs code kills, literally

* Fri Apr 11 2003 Rik van Riel <riel@redhat.com>
- merge S390(x) back in  (Pete Zaitcev)
- fix NFS kmap_atomic patch
- sched.c patch to disable interrupts in wake_forked_task  (Julie DeWandel)

* Thu Apr 10 2003 Rik van Riel <riel@redhat.com>
- AIO infrastructure  (Ben LaHaise)
- update NFS kmap_atomic patch  (Steve Dickson)

* Wed Apr  9 2003 Rik van Riel <riel@redhat.com>
- semtimedop patches  (Ernie Petrides)

* Tue Apr  8 2003 Rik van Riel <riel@redhat.com>
- I know understand linux-2.4.20-nfs-readeof.patch, so I merged it
- netdump update (Dave Anderson)
- 64 bit pci & elf loader fix (Mark & Julie)
- nptl whitespace patches, folded into nptl patch (Arjan van de Ven)
- rediff linux-2.4.18-smallpatches.patch

* Mon Apr  7 2003 Rik van Riel <riel@redhat.com>
- merge NFS patches by Steve Dickson (blame me for NFS kmap_atomic patch)
- split x86 syscall stuff out into separate patch

* Sat Apr  5 2003 Rik van Riel <riel@redhat.com>
- fix nptl patch, now it boots

* Fri Apr  4 2003 Rik van Riel <riel@redhat.com>
- port linux-2.4.20-o1-nptl.patch from gingin
- rediff a few patches

* Tue Apr  2 2003 Rik van Riel <riel@redhat.com>
- update linux-modules-unsupported (with Arjan)
- fix up the list a second time to fix module dependencies

* Mon Apr  1 2003 Rik van Riel <riel@redhat.com>
- copy -head into new AS3 branch
- remove i586 build
- remove 7.x compatibility (linux-2.4.9-fstat.patch)
- architecture patches get more breathing room (100 - 500)
- reserve patch numbers 1000 - 2000 for VM
- patch numbers 2000 - 5000 for bugfixes, changes and updates to
  existing drivers and filesystems
- remove inode reclaim patch (will be merged later as part of rmap)
- remove io priority scheduler (still experimental)
- remove nfs patches (linux-2.4.20-nfs-cto.patch,
  linux-2.4.20-nfs-access.patch & linux-2.4.20-nfs-rdplus.patch)
- remove linux-2.4.18-gericom.patch
- update netdump from RH9 branch

* Fri Mar 21 2003 Steve Dickson <SteveD@RedHat.com>
- Added three NFS performance patches

* Fri Mar 21 2003 Arjan van de Ven <arjanv@redhat.com>
- add a timer for aging requests up

* Thu Mar 20 2003 Arjan van de Ven <arjanv@redhat.com>
- fix the sorting in the io elevator

* Wed Mar 19 2003 Arjan van de Ven <arjanv@redhat.com>
- remerge ext3 orlov allocator and enable
- more priority io elevator infrastructure work

* Sat Mar 08 2003 Arjan van de Ven <arjanv@redhat.com>
- merge ext3 orlov allocator

* Thu Mar 04 2003 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.21-pre5-ac1
- split the rpm into a primary fileset and secondary (rare modules) fileset

* Wed Feb 26 2003 Arjan van de Ven <arjanv@redhat.com>
- go to 2.4.21-pre4-ac6
- drop lots of patches
- trim changelog to not have 2000, 2001 and 2002 anymore


* Mon Feb 17 2003 Arjan van de Ven <arjanv@redhat.com>
- downgrade pwc webcam driver one notch to the last known working version
- work around vm livelock
- make the cciss driver not enable irq's in it's irq handler

* Thu Feb 13 2003 Benjamin LaHaise <bcrl@redhat.com>
- fix for shared statistic < 0

* Thu Feb 13 2003 Arjan van de Ven <arjanv@redhat.com>
- Signal fixes for LSB testsuite
- merge patch to fix init=/bin/sh
- 2.4.21-pre4-ac4 bugfixes (mostly IDE crashes)

* Mon Feb 09 2003 Arjan van de Ven <arjanv@redhat.com>
- merge 2.4.21-pre4-ac3 bugfixes 

* Tue Feb  4 2003 Stephen C. Tweedie <sct@redhat.com>
- Add ext3 fix for truncating negative i_blocks

* Mon Feb 03 2003 Benjamin LaHaise <bcrl@redhat.com>
- add oopsmeharder for debugging hard hangs

* Mon Feb 03 2003 Arjan van de Ven <arjanv@redhat.com>
- merge rmap15d
- set the sbp2 command buffer to 64 elements instead of 8

* Wed Jan 29 2003 Arjan van de Ven <arjanv@redhat.com>
- merge tcp stall fix from DaveM
- merge bugfixes from 2.4.21-pre4

* Mon Jan 13 2003 Steve Dickson <SteveD@RedHat.com>
- Merge in the ACL and XATTR patches from the UL and BestBits trees.

* Sat Jan 11 2003 Stephen C. Tweedie <sct@redhat.com>
- Merge in the LVM pvmove fix to current tree

* Wed Jan 8 2003 Benjamin LaHaise <bcrl@redhat.com>
- add AMD Golem fixup
